Documentation
¶
Index ¶
- Variables
- type Org
- type Payer
- func (*Payer) Descriptor() ([]byte, []int)deprecated
- func (x *Payer) GetId() string
- func (x *Payer) GetMembers() []*api.Account
- func (x *Payer) GetMetadata() []*api.KeyValue
- func (x *Payer) GetName() string
- func (*Payer) ProtoMessage()
- func (x *Payer) ProtoReflect() protoreflect.Message
- func (x *Payer) Reset()
- func (x *Payer) String() string
- type Reseller
- func (*Reseller) Descriptor() ([]byte, []int)deprecated
- func (x *Reseller) GetAquaMeta() *api.FeatureFlags
- func (x *Reseller) GetEmail() string
- func (x *Reseller) GetGroupId() string
- func (x *Reseller) GetGroupName() string
- func (x *Reseller) GetGroupType() string
- func (x *Reseller) GetPassword() string
- func (x *Reseller) GetPasswordUpdateTime() string
- func (x *Reseller) GetUpdateTime() string
- func (x *Reseller) GetUserAccessId() string
- func (x *Reseller) GetUserId() string
- func (x *Reseller) GetWaveAvailabilityDays() int32
- func (x *Reseller) GetWaveMeta() *api.FeatureFlags
- func (x *Reseller) GetWaveRegistered() string
- func (x *Reseller) GetWaveStatus() string
- func (*Reseller) ProtoMessage()
- func (x *Reseller) ProtoReflect() protoreflect.Message
- func (x *Reseller) Reset()
- func (x *Reseller) String() string
Constants ¶
This section is empty.
Variables ¶
var File_api_ripple_org_proto protoreflect.FileDescriptor
var File_api_ripple_payer_proto protoreflect.FileDescriptor
var File_api_ripple_reseller_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Org ¶
type Org struct {
// The unique name (or id) of the organization.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The registered email of the organization.
Email string `protobuf:"bytes,2,opt,name=email,proto3" json:"email,omitempty"`
// The metadata (key/value pair) of the organization. If hierarchy is supported, it will be
// separated by '/', such as 'metakey/subkey=value'. See https://alphauslabs.github.io/blueapi/
// for the list of supported attributes.
Metadata map[string]string `` /* 157-byte string literal not displayed */
// contains filtered or unexported fields
}
Org resource definition.
func (*Org) Descriptor
deprecated
func (*Org) GetMetadata ¶
func (*Org) ProtoMessage ¶
func (*Org) ProtoMessage()
func (*Org) ProtoReflect ¶
func (x *Org) ProtoReflect() protoreflect.Message
type Payer ¶ added in v0.47.3
type Payer struct {
// The payer account id.
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// The payer account name.
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
// The attributes (key/value pair) of the account.
Metadata []*api.KeyValue `protobuf:"bytes,3,rep,name=metadata,proto3" json:"metadata,omitempty"`
// List of all members under this payer.
Members []*api.Account `protobuf:"bytes,4,rep,name=members,proto3" json:"members,omitempty"`
// contains filtered or unexported fields
}
Payer resource definition.
func (*Payer) Descriptor
deprecated
added in
v0.47.3
func (*Payer) GetMembers ¶ added in v0.47.4
func (*Payer) GetMetadata ¶ added in v0.47.3
func (*Payer) ProtoMessage ¶ added in v0.47.3
func (*Payer) ProtoMessage()
func (*Payer) ProtoReflect ¶ added in v0.47.3
func (x *Payer) ProtoReflect() protoreflect.Message
type Reseller ¶ added in v0.48.2
type Reseller struct {
// The email address associated with the account. If there is no email
// address provided then this field will contain "Not Set"
Email string `protobuf:"bytes,1,opt,name=email,proto3" json:"email,omitempty"`
// The password associated with the account. This field will only be
// populated when the reseller is first created
Password string `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
// The ID of the group to which the user belongs. This will either
// be a billing group ID or an access group ID
GroupId string `protobuf:"bytes,3,opt,name=groupId,proto3" json:"groupId,omitempty"`
// The name of the group to which the user belongs. This will either
// be the name of a billing group or an access group
GroupName string `protobuf:"bytes,4,opt,name=groupName,proto3" json:"groupName,omitempty"`
// This field describes what type of group to which the user belongs.
// This field will contain either a value of "billing_group" or "access_group"
GroupType string `protobuf:"bytes,5,opt,name=groupType,proto3" json:"groupType,omitempty"`
// A collection of feature flags for Wave and whether or not they should be
// enabled. For a full list of such flags, see https://alphauslabs.github.io/blueapi/apis/admin.html.
WaveMeta *api.FeatureFlags `protobuf:"bytes,6,opt,name=waveMeta,proto3" json:"waveMeta,omitempty"`
// A collection of feature flags for Aqua and whether or not they should be
// enabled. For a full list of such flags, see https://alphauslabs.github.io/blueapi/apis/admin.html.
AquaMeta *api.FeatureFlags `protobuf:"bytes,7,opt,name=aquaMeta,proto3" json:"aquaMeta,omitempty"`
// The time when the password was last updated. This value will be null if
// the password has never been updated
PasswordUpdateTime string `protobuf:"bytes,8,opt,name=passwordUpdateTime,proto3" json:"passwordUpdateTime,omitempty"`
// The time when the user was last updated. This value will be null if the
// user has never been updated
UpdateTime string `protobuf:"bytes,9,opt,name=updateTime,proto3" json:"updateTime,omitempty"`
// An ID that uniquely identifies the user in the context of its access group.
// If the user does not belong to an access group then this value field will
// contain the same value as the user ID
UserAccessId string `protobuf:"bytes,10,opt,name=userAccessId,proto3" json:"userAccessId,omitempty"`
// An ID that unqiuely identifies the user
UserId string `protobuf:"bytes,11,opt,name=userId,proto3" json:"userId,omitempty"`
// How many days of Wave use remain. This value is only used for trial accounts.
// This field cannot be updated.
WaveAvailabilityDays int32 `protobuf:"varint,12,opt,name=waveAvailabilityDays,proto3" json:"waveAvailabilityDays,omitempty"`
// When the user registered on Wave.
WaveRegistered string `protobuf:"bytes,13,opt,name=waveRegistered,proto3" json:"waveRegistered,omitempty"`
// The plan associated with the Wave user. Possible values include "trial",
// "limited3" and "limited4"
WaveStatus string `protobuf:"bytes,14,opt,name=waveStatus,proto3" json:"waveStatus,omitempty"`
// contains filtered or unexported fields
}
Describes the fields on a Wave root (reseller) account
func (*Reseller) Descriptor
deprecated
added in
v0.48.2
func (*Reseller) GetAquaMeta ¶ added in v0.48.2
func (x *Reseller) GetAquaMeta() *api.FeatureFlags
func (*Reseller) GetGroupId ¶ added in v0.48.2
func (*Reseller) GetGroupName ¶ added in v0.48.2
func (*Reseller) GetGroupType ¶ added in v0.48.2
func (*Reseller) GetPassword ¶ added in v0.48.2
func (*Reseller) GetPasswordUpdateTime ¶ added in v0.48.2
func (*Reseller) GetUpdateTime ¶ added in v0.48.2
func (*Reseller) GetUserAccessId ¶ added in v0.48.2
func (*Reseller) GetWaveAvailabilityDays ¶ added in v0.48.2
func (*Reseller) GetWaveMeta ¶ added in v0.48.2
func (x *Reseller) GetWaveMeta() *api.FeatureFlags
func (*Reseller) GetWaveRegistered ¶ added in v0.48.2
func (*Reseller) GetWaveStatus ¶ added in v0.48.2
func (*Reseller) ProtoMessage ¶ added in v0.48.2
func (*Reseller) ProtoMessage()
func (*Reseller) ProtoReflect ¶ added in v0.48.2
func (x *Reseller) ProtoReflect() protoreflect.Message
Click to show internal directories.
Click to hide internal directories.