v1

package
v0.74.99 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 21, 2025 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	SupportPlan_name = map[int32]string{
		0: "NO_SUPPORT",
		1: "AWS_DEVELOPER",
		2: "AWS_BUSINESS",
		3: "AWS_ENTERPRISE",
		4: "AWS_ENTERPRISE_ON_RAMP",
	}
	SupportPlan_value = map[string]int32{
		"NO_SUPPORT":             0,
		"AWS_DEVELOPER":          1,
		"AWS_BUSINESS":           2,
		"AWS_ENTERPRISE":         3,
		"AWS_ENTERPRISE_ON_RAMP": 4,
	}
)

Enum value maps for SupportPlan.

var File_api_ripple_v1_accountsupportplan_proto protoreflect.FileDescriptor
var File_api_ripple_v1_adjustmententry_proto protoreflect.FileDescriptor
var File_api_ripple_v1_dashboard_proto protoreflect.FileDescriptor
var File_api_ripple_v1_export_proto protoreflect.FileDescriptor
var File_api_ripple_v1_invoiceservicediscounts_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type AccountServiceDiscountsExport added in v0.74.14

type AccountServiceDiscountsExport struct {
	Data *ExportData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// Empty if direct link in request is disabled in request
	DirectLink string `protobuf:"bytes,2,opt,name=directLink,proto3" json:"directLink,omitempty"`
	// contains filtered or unexported fields
}

AccountServiceDiscountsExport resource definition.

data is [blueapi.api.ripple.v1.ExportData]

content. Base64 encoded value. For example, content :`YmlsbGluZ0dyb3VwSWQsYmlsbGluZ0dyb3VwTmFtZSxWZW5kb3IsQWNjb3VudElkLEFjY291bnROYW1lLFNlcnZpY2UgUHJlbWl1bXMmRGlzY291bnRzDQo=` Decoding this value by en, get `billingGroupId,billingGroupName,Vendor,AccountId,AccountName,Service Premiums&Discounts`. content :`6KuL5rGC44Kw44Or44O844OXSUQs6KuL5rGC44Kw44Or44O844OX5ZCNLOODmeODs+ODgOODvCzjgqLjgqvjgqbjg7Pjg4hJRCzjgqLjgqvjgqbjg7Pjg4jlkI0s44K144O844OT44K55Ymy5byV44O75Ymy5aKX6Kit5a6aDQo=` Decoding this value by ja, get `請求グループID,請求グループ名,ベンダー,アカウントID,アカウント名,サービス割引・割増設定`.

downloadedRows. Downloaded content lines.

totalRows.Total of content lines.

func (*AccountServiceDiscountsExport) Descriptor deprecated added in v0.74.14

func (*AccountServiceDiscountsExport) Descriptor() ([]byte, []int)

Deprecated: Use AccountServiceDiscountsExport.ProtoReflect.Descriptor instead.

func (*AccountServiceDiscountsExport) GetData added in v0.74.14

func (x *AccountServiceDiscountsExport) GetDirectLink() string

func (*AccountServiceDiscountsExport) ProtoMessage added in v0.74.14

func (*AccountServiceDiscountsExport) ProtoMessage()

func (*AccountServiceDiscountsExport) ProtoReflect added in v0.74.14

func (*AccountServiceDiscountsExport) Reset added in v0.74.14

func (x *AccountServiceDiscountsExport) Reset()

func (*AccountServiceDiscountsExport) String added in v0.74.14

type AdjustmentEntry added in v0.74.85

type AdjustmentEntry struct {

	// The adjustment entry ID.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// The adjustment entry name.
	Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// Account info.
	Account *AdjustmentEntryAccountInfo `protobuf:"bytes,3,opt,name=account,proto3" json:"account,omitempty"`
	// Adjustment entry info.
	Entry *AdjustmentEntryInfo `protobuf:"bytes,4,opt,name=entry,proto3" json:"entry,omitempty"`
	// Adjustment entry setting.
	Setting *AdjustmentEntrySetting `protobuf:"bytes,5,opt,name=setting,proto3" json:"setting,omitempty"`
	// contains filtered or unexported fields
}

AdjustmentEntry resource definition.

func (*AdjustmentEntry) Descriptor deprecated added in v0.74.85

func (*AdjustmentEntry) Descriptor() ([]byte, []int)

Deprecated: Use AdjustmentEntry.ProtoReflect.Descriptor instead.

func (*AdjustmentEntry) GetAccount added in v0.74.85

func (*AdjustmentEntry) GetEntry added in v0.74.85

func (x *AdjustmentEntry) GetEntry() *AdjustmentEntryInfo

func (*AdjustmentEntry) GetId added in v0.74.85

func (x *AdjustmentEntry) GetId() string

func (*AdjustmentEntry) GetName added in v0.74.85

func (x *AdjustmentEntry) GetName() string

func (*AdjustmentEntry) GetSetting added in v0.74.85

func (x *AdjustmentEntry) GetSetting() *AdjustmentEntrySetting

func (*AdjustmentEntry) ProtoMessage added in v0.74.85

func (*AdjustmentEntry) ProtoMessage()

func (*AdjustmentEntry) ProtoReflect added in v0.74.85

func (x *AdjustmentEntry) ProtoReflect() protoreflect.Message

func (*AdjustmentEntry) Reset added in v0.74.85

func (x *AdjustmentEntry) Reset()

func (*AdjustmentEntry) String added in v0.74.85

func (x *AdjustmentEntry) String() string

type AdjustmentEntryAccountInfo added in v0.74.85

type AdjustmentEntryAccountInfo struct {

	// The account ID.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// The account name.
	Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// The vendor.
	Vendor string `protobuf:"bytes,3,opt,name=vendor,proto3" json:"vendor,omitempty"`
	// The billing internal ID.
	BillingInternalId string `protobuf:"bytes,4,opt,name=billingInternalId,proto3" json:"billingInternalId,omitempty"`
	// The billing group ID.
	BillingGroupId string `protobuf:"bytes,5,opt,name=billingGroupId,proto3" json:"billingGroupId,omitempty"`
	// The billing group name.
	BillingGroupName string `protobuf:"bytes,6,opt,name=billingGroupName,proto3" json:"billingGroupName,omitempty"`
	// The billing group currency.
	Currency string `protobuf:"bytes,7,opt,name=currency,proto3" json:"currency,omitempty"`
	// contains filtered or unexported fields
}

AdjustmentEntryAccountInfo resource definition.

func (*AdjustmentEntryAccountInfo) Descriptor deprecated added in v0.74.85

func (*AdjustmentEntryAccountInfo) Descriptor() ([]byte, []int)

Deprecated: Use AdjustmentEntryAccountInfo.ProtoReflect.Descriptor instead.

func (*AdjustmentEntryAccountInfo) GetBillingGroupId added in v0.74.85

func (x *AdjustmentEntryAccountInfo) GetBillingGroupId() string

func (*AdjustmentEntryAccountInfo) GetBillingGroupName added in v0.74.85

func (x *AdjustmentEntryAccountInfo) GetBillingGroupName() string

func (*AdjustmentEntryAccountInfo) GetBillingInternalId added in v0.74.85

func (x *AdjustmentEntryAccountInfo) GetBillingInternalId() string

func (*AdjustmentEntryAccountInfo) GetCurrency added in v0.74.85

func (x *AdjustmentEntryAccountInfo) GetCurrency() string

func (*AdjustmentEntryAccountInfo) GetId added in v0.74.85

func (*AdjustmentEntryAccountInfo) GetName added in v0.74.85

func (x *AdjustmentEntryAccountInfo) GetName() string

func (*AdjustmentEntryAccountInfo) GetVendor added in v0.74.85

func (x *AdjustmentEntryAccountInfo) GetVendor() string

func (*AdjustmentEntryAccountInfo) ProtoMessage added in v0.74.85

func (*AdjustmentEntryAccountInfo) ProtoMessage()

func (*AdjustmentEntryAccountInfo) ProtoReflect added in v0.74.85

func (*AdjustmentEntryAccountInfo) Reset added in v0.74.85

func (x *AdjustmentEntryAccountInfo) Reset()

func (*AdjustmentEntryAccountInfo) String added in v0.74.85

func (x *AdjustmentEntryAccountInfo) String() string

type AdjustmentEntryInfo added in v0.74.85

type AdjustmentEntryInfo struct {

	// The calculation type.
	CalculationType string `protobuf:"bytes,1,opt,name=calculationType,proto3" json:"calculationType,omitempty"`
	// The adjustment entry type.
	AdjustmentEntryType string `protobuf:"bytes,2,opt,name=adjustmentEntryType,proto3" json:"adjustmentEntryType,omitempty"`
	// The adjustment entry description.
	Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
	// The product code.
	ProductCode string `protobuf:"bytes,4,opt,name=productCode,proto3" json:"productCode,omitempty"`
	// The product name.
	ProductName string `protobuf:"bytes,5,opt,name=productName,proto3" json:"productName,omitempty"`
	// The currency.
	Currency string `protobuf:"bytes,6,opt,name=currency,proto3" json:"currency,omitempty"`
	// The amount.
	Amount float64 `protobuf:"fixed64,7,opt,name=amount,proto3" json:"amount,omitempty"`
	// The time interval.
	TimeInterval string `protobuf:"bytes,8,opt,name=timeInterval,proto3" json:"timeInterval,omitempty"`
	// The usage start.
	UsageStart string `protobuf:"bytes,9,opt,name=usageStart,proto3" json:"usageStart,omitempty"`
	// contains filtered or unexported fields
}

AdjustmentEntryInfo resource definition.

func (*AdjustmentEntryInfo) Descriptor deprecated added in v0.74.85

func (*AdjustmentEntryInfo) Descriptor() ([]byte, []int)

Deprecated: Use AdjustmentEntryInfo.ProtoReflect.Descriptor instead.

func (*AdjustmentEntryInfo) GetAdjustmentEntryType added in v0.74.85

func (x *AdjustmentEntryInfo) GetAdjustmentEntryType() string

func (*AdjustmentEntryInfo) GetAmount added in v0.74.85

func (x *AdjustmentEntryInfo) GetAmount() float64

func (*AdjustmentEntryInfo) GetCalculationType added in v0.74.85

func (x *AdjustmentEntryInfo) GetCalculationType() string

func (*AdjustmentEntryInfo) GetCurrency added in v0.74.85

func (x *AdjustmentEntryInfo) GetCurrency() string

func (*AdjustmentEntryInfo) GetDescription added in v0.74.85

func (x *AdjustmentEntryInfo) GetDescription() string

func (*AdjustmentEntryInfo) GetProductCode added in v0.74.85

func (x *AdjustmentEntryInfo) GetProductCode() string

func (*AdjustmentEntryInfo) GetProductName added in v0.74.85

func (x *AdjustmentEntryInfo) GetProductName() string

func (*AdjustmentEntryInfo) GetTimeInterval added in v0.74.85

func (x *AdjustmentEntryInfo) GetTimeInterval() string

func (*AdjustmentEntryInfo) GetUsageStart added in v0.74.85

func (x *AdjustmentEntryInfo) GetUsageStart() string

func (*AdjustmentEntryInfo) ProtoMessage added in v0.74.85

func (*AdjustmentEntryInfo) ProtoMessage()

func (*AdjustmentEntryInfo) ProtoReflect added in v0.74.85

func (x *AdjustmentEntryInfo) ProtoReflect() protoreflect.Message

func (*AdjustmentEntryInfo) Reset added in v0.74.85

func (x *AdjustmentEntryInfo) Reset()

func (*AdjustmentEntryInfo) String added in v0.74.85

func (x *AdjustmentEntryInfo) String() string

type AdjustmentEntrySetting added in v0.74.85

type AdjustmentEntrySetting struct {

	// Applied to the billing.
	Apply bool `protobuf:"varint,1,opt,name=apply,proto3" json:"apply,omitempty"`
	// The exchange rate applied to the billing.
	ExchangeRate float64 `protobuf:"fixed64,2,opt,name=exchangeRate,proto3" json:"exchangeRate,omitempty"`
	// The tax free applied to the billing.
	TaxFree bool `protobuf:"varint,3,opt,name=taxFree,proto3" json:"taxFree,omitempty"`
	// The allocate type indicates the type to which an entry has been allocated.
	AllocateType string `protobuf:"bytes,4,opt,name=allocateType,proto3" json:"allocateType,omitempty"`
	// The split type indicates the type to which an entry has been splitted.
	SplitType string `protobuf:"bytes,5,opt,name=splitType,proto3" json:"splitType,omitempty"`
	// The original ID represents the originally allocated or splitted ID.
	OriginalId string `protobuf:"bytes,6,opt,name=originalId,proto3" json:"originalId,omitempty"`
	// The Splitted indicates whether it has been split.
	Splitted bool `protobuf:"varint,7,opt,name=splitted,proto3" json:"splitted,omitempty"`
	// The term indicates the number of years that can be splitted.
	// For 1 year, it is divided into 12 parts.
	// For 3 years, it is divided into 36 parts.
	Term int32 `protobuf:"varint,8,opt,name=term,proto3" json:"term,omitempty"`
	// contains filtered or unexported fields
}

AdjustmentEntrySetting resource definition.

func (*AdjustmentEntrySetting) Descriptor deprecated added in v0.74.85

func (*AdjustmentEntrySetting) Descriptor() ([]byte, []int)

Deprecated: Use AdjustmentEntrySetting.ProtoReflect.Descriptor instead.

func (*AdjustmentEntrySetting) GetAllocateType added in v0.74.85

func (x *AdjustmentEntrySetting) GetAllocateType() string

func (*AdjustmentEntrySetting) GetApply added in v0.74.85

func (x *AdjustmentEntrySetting) GetApply() bool

func (*AdjustmentEntrySetting) GetExchangeRate added in v0.74.85

func (x *AdjustmentEntrySetting) GetExchangeRate() float64

func (*AdjustmentEntrySetting) GetOriginalId added in v0.74.85

func (x *AdjustmentEntrySetting) GetOriginalId() string

func (*AdjustmentEntrySetting) GetSplitType added in v0.74.85

func (x *AdjustmentEntrySetting) GetSplitType() string

func (*AdjustmentEntrySetting) GetSplitted added in v0.74.88

func (x *AdjustmentEntrySetting) GetSplitted() bool

func (*AdjustmentEntrySetting) GetTaxFree added in v0.74.85

func (x *AdjustmentEntrySetting) GetTaxFree() bool

func (*AdjustmentEntrySetting) GetTerm added in v0.74.88

func (x *AdjustmentEntrySetting) GetTerm() int32

func (*AdjustmentEntrySetting) ProtoMessage added in v0.74.85

func (*AdjustmentEntrySetting) ProtoMessage()

func (*AdjustmentEntrySetting) ProtoReflect added in v0.74.85

func (x *AdjustmentEntrySetting) ProtoReflect() protoreflect.Message

func (*AdjustmentEntrySetting) Reset added in v0.74.85

func (x *AdjustmentEntrySetting) Reset()

func (*AdjustmentEntrySetting) String added in v0.74.85

func (x *AdjustmentEntrySetting) String() string

type BillingGroupAccountSupportPlan added in v0.74.80

type BillingGroupAccountSupportPlan struct {

	// The account id.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// The account name.
	Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// The support plan.
	Plan SupportPlan `protobuf:"varint,3,opt,name=plan,proto3,enum=blueapi.api.ripple.v1.SupportPlan" json:"plan,omitempty"`
	// contains filtered or unexported fields
}

Billing Group Account Support Plan resource definition.

func (*BillingGroupAccountSupportPlan) Descriptor deprecated added in v0.74.80

func (*BillingGroupAccountSupportPlan) Descriptor() ([]byte, []int)

Deprecated: Use BillingGroupAccountSupportPlan.ProtoReflect.Descriptor instead.

func (*BillingGroupAccountSupportPlan) GetId added in v0.74.80

func (*BillingGroupAccountSupportPlan) GetName added in v0.74.80

func (*BillingGroupAccountSupportPlan) GetPlan added in v0.74.80

func (*BillingGroupAccountSupportPlan) ProtoMessage added in v0.74.80

func (*BillingGroupAccountSupportPlan) ProtoMessage()

func (*BillingGroupAccountSupportPlan) ProtoReflect added in v0.74.80

func (*BillingGroupAccountSupportPlan) Reset added in v0.74.80

func (x *BillingGroupAccountSupportPlan) Reset()

func (*BillingGroupAccountSupportPlan) String added in v0.74.80

type BillingGroupSection added in v0.74.1

type BillingGroupSection struct {

	// The id. billing group id
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// The name. billing group name
	Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// The year-month. format: yyyymm
	YearMonth string `protobuf:"bytes,3,opt,name=yearMonth,proto3" json:"yearMonth,omitempty"`
	// The currency.
	Currency string `protobuf:"bytes,4,opt,name=currency,proto3" json:"currency,omitempty"`
	// The invoice cost.
	InvoiceCost float64 `protobuf:"fixed64,5,opt,name=invoiceCost,proto3" json:"invoiceCost,omitempty"`
	// The procurement cost.
	ProcurementCost float64 `protobuf:"fixed64,6,opt,name=procurementCost,proto3" json:"procurementCost,omitempty"`
	// The profit cost.
	ProfitCost float64 `protobuf:"fixed64,7,opt,name=profitCost,proto3" json:"profitCost,omitempty"`
	// contains filtered or unexported fields
}

BillingGroupSection resource definition.

func (*BillingGroupSection) Descriptor deprecated added in v0.74.1

func (*BillingGroupSection) Descriptor() ([]byte, []int)

Deprecated: Use BillingGroupSection.ProtoReflect.Descriptor instead.

func (*BillingGroupSection) GetCurrency added in v0.74.1

func (x *BillingGroupSection) GetCurrency() string

func (*BillingGroupSection) GetId added in v0.74.1

func (x *BillingGroupSection) GetId() string

func (*BillingGroupSection) GetInvoiceCost added in v0.74.58

func (x *BillingGroupSection) GetInvoiceCost() float64

func (*BillingGroupSection) GetName added in v0.74.1

func (x *BillingGroupSection) GetName() string

func (*BillingGroupSection) GetProcurementCost added in v0.74.1

func (x *BillingGroupSection) GetProcurementCost() float64

func (*BillingGroupSection) GetProfitCost added in v0.74.1

func (x *BillingGroupSection) GetProfitCost() float64

func (*BillingGroupSection) GetYearMonth added in v0.74.1

func (x *BillingGroupSection) GetYearMonth() string

func (*BillingGroupSection) ProtoMessage added in v0.74.1

func (*BillingGroupSection) ProtoMessage()

func (*BillingGroupSection) ProtoReflect added in v0.74.1

func (x *BillingGroupSection) ProtoReflect() protoreflect.Message

func (*BillingGroupSection) Reset added in v0.74.1

func (x *BillingGroupSection) Reset()

func (*BillingGroupSection) String added in v0.74.1

func (x *BillingGroupSection) String() string

type ExportData added in v0.74.14

type ExportData struct {

	// Base64 encoded value.
	Content string `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
	// Downloaded content lines.
	DownloadedRows int64 `protobuf:"varint,2,opt,name=downloadedRows,proto3" json:"downloadedRows,omitempty"`
	// Total of content lines.
	TotalRows int64 `protobuf:"varint,3,opt,name=totalRows,proto3" json:"totalRows,omitempty"`
	// contains filtered or unexported fields
}

ExportData resource definition.

func (*ExportData) Descriptor deprecated added in v0.74.14

func (*ExportData) Descriptor() ([]byte, []int)

Deprecated: Use ExportData.ProtoReflect.Descriptor instead.

func (*ExportData) GetContent added in v0.74.14

func (x *ExportData) GetContent() string

func (*ExportData) GetDownloadedRows added in v0.74.14

func (x *ExportData) GetDownloadedRows() int64

func (*ExportData) GetTotalRows added in v0.74.14

func (x *ExportData) GetTotalRows() int64

func (*ExportData) ProtoMessage added in v0.74.14

func (*ExportData) ProtoMessage()

func (*ExportData) ProtoReflect added in v0.74.14

func (x *ExportData) ProtoReflect() protoreflect.Message

func (*ExportData) Reset added in v0.74.14

func (x *ExportData) Reset()

func (*ExportData) String added in v0.74.14

func (x *ExportData) String() string

type GroupServiceDiscountsExport added in v0.74.14

type GroupServiceDiscountsExport struct {
	Data *ExportData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// Empty if direct link in request is disabled in request
	DirectLink string `protobuf:"bytes,2,opt,name=directLink,proto3" json:"directLink,omitempty"`
	// contains filtered or unexported fields
}

GroupServiceDiscountsExport resource definition. `Group` refer to `BillingGroup`.

data is [blueapi.api.ripple.v1.ExportData]

content. Base64 encoded value. For example, content :`YmlsbGluZ0dyb3VwSWQsYmlsbGluZ0dyb3VwTmFtZSxTZXJ2aWNlIFByZW1pdW1zJkRpc2NvdW50cw0K` Decoding this value by en, get `billingGroupId,billingGroupName,Service Premiums&Discounts`. content :`6KuL5rGC44Kw44Or44O844OXSUQs6KuL5rGC44Kw44Or44O844OX5ZCNLOOCteODvOODk+OCueWJsuW8leODu+WJsuWil+ioreWumg0K` Decoding this value by ja, get `請求グループID,請求グループ名,サービス割引・割増設定`.

downloadedRows. Downloaded content lines.

totalRows.Total of content lines.

func (*GroupServiceDiscountsExport) Descriptor deprecated added in v0.74.14

func (*GroupServiceDiscountsExport) Descriptor() ([]byte, []int)

Deprecated: Use GroupServiceDiscountsExport.ProtoReflect.Descriptor instead.

func (*GroupServiceDiscountsExport) GetData added in v0.74.14

func (x *GroupServiceDiscountsExport) GetDirectLink() string

func (*GroupServiceDiscountsExport) ProtoMessage added in v0.74.14

func (*GroupServiceDiscountsExport) ProtoMessage()

func (*GroupServiceDiscountsExport) ProtoReflect added in v0.74.14

func (*GroupServiceDiscountsExport) Reset added in v0.74.14

func (x *GroupServiceDiscountsExport) Reset()

func (*GroupServiceDiscountsExport) String added in v0.74.14

func (x *GroupServiceDiscountsExport) String() string

type InvoiceServiceDiscounts

type InvoiceServiceDiscounts struct {

	// The invoice service discounts id.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// The invoice service discount name.
	// must be 1-60 characters long.
	Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// The invoice service discount description.
	// Maximum 150 characters long.
	Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
	// The invoice service discount setting.
	Setting *InvoiceServiceDiscountsSetting `protobuf:"bytes,4,opt,name=setting,proto3" json:"setting,omitempty"`
	// Timestamp associated with the created.
	Created string `protobuf:"bytes,5,opt,name=created,proto3" json:"created,omitempty"`
	// Timestamp associated with the updated.
	Updated string `protobuf:"bytes,6,opt,name=updated,proto3" json:"updated,omitempty"`
	// contains filtered or unexported fields
}

InvoiceServiceDiscounts resource definition.

func (*InvoiceServiceDiscounts) Descriptor deprecated

func (*InvoiceServiceDiscounts) Descriptor() ([]byte, []int)

Deprecated: Use InvoiceServiceDiscounts.ProtoReflect.Descriptor instead.

func (*InvoiceServiceDiscounts) GetCreated

func (x *InvoiceServiceDiscounts) GetCreated() string

func (*InvoiceServiceDiscounts) GetDescription

func (x *InvoiceServiceDiscounts) GetDescription() string

func (*InvoiceServiceDiscounts) GetId

func (x *InvoiceServiceDiscounts) GetId() string

func (*InvoiceServiceDiscounts) GetName

func (x *InvoiceServiceDiscounts) GetName() string

func (*InvoiceServiceDiscounts) GetSetting

func (*InvoiceServiceDiscounts) GetUpdated

func (x *InvoiceServiceDiscounts) GetUpdated() string

func (*InvoiceServiceDiscounts) ProtoMessage

func (*InvoiceServiceDiscounts) ProtoMessage()

func (*InvoiceServiceDiscounts) ProtoReflect

func (x *InvoiceServiceDiscounts) ProtoReflect() protoreflect.Message

func (*InvoiceServiceDiscounts) Reset

func (x *InvoiceServiceDiscounts) Reset()

func (*InvoiceServiceDiscounts) String

func (x *InvoiceServiceDiscounts) String() string

type InvoiceServiceDiscountsSetting

type InvoiceServiceDiscountsSetting struct {

	// The invoice service discounts setting details.
	AwsDetails []*InvoiceServiceDiscountsSettingDetails `protobuf:"bytes,1,rep,name=awsDetails,proto3" json:"awsDetails,omitempty"`
	// The invoice service discounts setting details.
	AzureDetails []*InvoiceServiceDiscountsSettingDetails `protobuf:"bytes,2,rep,name=azureDetails,proto3" json:"azureDetails,omitempty"`
	// The invoice service discounts setting details.
	GcpDetails []*InvoiceServiceDiscountsSettingDetails `protobuf:"bytes,3,rep,name=gcpDetails,proto3" json:"gcpDetails,omitempty"`
	// contains filtered or unexported fields
}

InvoiceServiceDiscountsSetting resource definition.

func (*InvoiceServiceDiscountsSetting) Descriptor deprecated

func (*InvoiceServiceDiscountsSetting) Descriptor() ([]byte, []int)

Deprecated: Use InvoiceServiceDiscountsSetting.ProtoReflect.Descriptor instead.

func (*InvoiceServiceDiscountsSetting) GetAwsDetails

func (*InvoiceServiceDiscountsSetting) GetAzureDetails

func (*InvoiceServiceDiscountsSetting) GetGcpDetails

func (*InvoiceServiceDiscountsSetting) ProtoMessage

func (*InvoiceServiceDiscountsSetting) ProtoMessage()

func (*InvoiceServiceDiscountsSetting) ProtoReflect

func (*InvoiceServiceDiscountsSetting) Reset

func (x *InvoiceServiceDiscountsSetting) Reset()

func (*InvoiceServiceDiscountsSetting) String

type InvoiceServiceDiscountsSettingDetails

type InvoiceServiceDiscountsSettingDetails struct {

	// The vendor service code.
	// aws: ProductCode
	// azure: ServiceCode
	// gcp: ServiceName
	// `otherServices`: The code to specify other services as a whole, regardless of vendor.
	// For exmaple: Other services set at 1%.
	// {"code":"otherServices", "value":0.01}
	Code string `protobuf:"bytes,1,opt,name=code,proto3" json:"code,omitempty"`
	// The vendor service name.
	Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// Value associated with the set premiums or discounts.
	Value float64 `protobuf:"fixed64,3,opt,name=value,proto3" json:"value,omitempty"`
	// The calculation scope.
	// default is `disabled`.
	// If enabled, Usage and any lineitem type including Fee are included in the calculation.
	// If disabled, only the Usage is included in the calculation.
	CalculationScope bool `protobuf:"varint,4,opt,name=calculationScope,proto3" json:"calculationScope,omitempty"`
	// contains filtered or unexported fields
}

InvoiceServiceDiscountsSettingDetails resource definition.

func (*InvoiceServiceDiscountsSettingDetails) Descriptor deprecated

func (*InvoiceServiceDiscountsSettingDetails) Descriptor() ([]byte, []int)

Deprecated: Use InvoiceServiceDiscountsSettingDetails.ProtoReflect.Descriptor instead.

func (*InvoiceServiceDiscountsSettingDetails) GetCalculationScope

func (x *InvoiceServiceDiscountsSettingDetails) GetCalculationScope() bool

func (*InvoiceServiceDiscountsSettingDetails) GetCode

func (*InvoiceServiceDiscountsSettingDetails) GetName

func (*InvoiceServiceDiscountsSettingDetails) GetValue

func (*InvoiceServiceDiscountsSettingDetails) ProtoMessage

func (*InvoiceServiceDiscountsSettingDetails) ProtoMessage()

func (*InvoiceServiceDiscountsSettingDetails) ProtoReflect

func (*InvoiceServiceDiscountsSettingDetails) Reset

func (*InvoiceServiceDiscountsSettingDetails) String

type OverViewOptionSection added in v0.74.1

type OverViewOptionSection struct {

	// The spp discount cost.
	SppDiscountCost float64 `protobuf:"fixed64,1,opt,name=sppDiscountCost,proto3" json:"sppDiscountCost,omitempty"`
	// contains filtered or unexported fields
}

OverViewOptionSection resource definition.

func (*OverViewOptionSection) Descriptor deprecated added in v0.74.1

func (*OverViewOptionSection) Descriptor() ([]byte, []int)

Deprecated: Use OverViewOptionSection.ProtoReflect.Descriptor instead.

func (*OverViewOptionSection) GetSppDiscountCost added in v0.74.1

func (x *OverViewOptionSection) GetSppDiscountCost() float64

func (*OverViewOptionSection) ProtoMessage added in v0.74.1

func (*OverViewOptionSection) ProtoMessage()

func (*OverViewOptionSection) ProtoReflect added in v0.74.1

func (x *OverViewOptionSection) ProtoReflect() protoreflect.Message

func (*OverViewOptionSection) Reset added in v0.74.1

func (x *OverViewOptionSection) Reset()

func (*OverViewOptionSection) String added in v0.74.1

func (x *OverViewOptionSection) String() string

type OverViewSection added in v0.74.1

type OverViewSection struct {

	// The id. id:OverViewSection.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// The name. name:OverViewSection.
	Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// The currency.
	Currency string `protobuf:"bytes,3,opt,name=currency,proto3" json:"currency,omitempty"`
	// The invoice cost.
	InvoiceCost float64 `protobuf:"fixed64,4,opt,name=invoiceCost,proto3" json:"invoiceCost,omitempty"`
	// The procurement cost.
	ProcurementCost float64 `protobuf:"fixed64,5,opt,name=procurementCost,proto3" json:"procurementCost,omitempty"`
	// The profit cost.
	ProfitCost float64 `protobuf:"fixed64,6,opt,name=profitCost,proto3" json:"profitCost,omitempty"`
	// The options.
	Options *OverViewOptionSection `protobuf:"bytes,7,opt,name=options,proto3" json:"options,omitempty"`
	// The period over period.
	PeriodOverPeriod *PeriodOverPeriodSection `protobuf:"bytes,8,opt,name=periodOverPeriod,proto3" json:"periodOverPeriod,omitempty"`
	// The aws section.
	AwsSection *VendorOverViewSection `protobuf:"bytes,9,opt,name=awsSection,proto3" json:"awsSection,omitempty"`
	// The azure section.
	AzureSection *VendorOverViewSection `protobuf:"bytes,10,opt,name=azureSection,proto3" json:"azureSection,omitempty"`
	// The gcp section.
	GcpSection *VendorOverViewSection `protobuf:"bytes,11,opt,name=gcpSection,proto3" json:"gcpSection,omitempty"`
	// contains filtered or unexported fields
}

OverViewSection resource definition.

func (*OverViewSection) Descriptor deprecated added in v0.74.1

func (*OverViewSection) Descriptor() ([]byte, []int)

Deprecated: Use OverViewSection.ProtoReflect.Descriptor instead.

func (*OverViewSection) GetAwsSection added in v0.74.1

func (x *OverViewSection) GetAwsSection() *VendorOverViewSection

func (*OverViewSection) GetAzureSection added in v0.74.1

func (x *OverViewSection) GetAzureSection() *VendorOverViewSection

func (*OverViewSection) GetCurrency added in v0.74.1

func (x *OverViewSection) GetCurrency() string

func (*OverViewSection) GetGcpSection added in v0.74.1

func (x *OverViewSection) GetGcpSection() *VendorOverViewSection

func (*OverViewSection) GetId added in v0.74.1

func (x *OverViewSection) GetId() string

func (*OverViewSection) GetInvoiceCost added in v0.74.1

func (x *OverViewSection) GetInvoiceCost() float64

func (*OverViewSection) GetName added in v0.74.1

func (x *OverViewSection) GetName() string

func (*OverViewSection) GetOptions added in v0.74.1

func (x *OverViewSection) GetOptions() *OverViewOptionSection

func (*OverViewSection) GetPeriodOverPeriod added in v0.74.1

func (x *OverViewSection) GetPeriodOverPeriod() *PeriodOverPeriodSection

func (*OverViewSection) GetProcurementCost added in v0.74.1

func (x *OverViewSection) GetProcurementCost() float64

func (*OverViewSection) GetProfitCost added in v0.74.1

func (x *OverViewSection) GetProfitCost() float64

func (*OverViewSection) ProtoMessage added in v0.74.1

func (*OverViewSection) ProtoMessage()

func (*OverViewSection) ProtoReflect added in v0.74.1

func (x *OverViewSection) ProtoReflect() protoreflect.Message

func (*OverViewSection) Reset added in v0.74.1

func (x *OverViewSection) Reset()

func (*OverViewSection) String added in v0.74.1

func (x *OverViewSection) String() string

type PeriodOverPeriodOptionSection added in v0.74.1

type PeriodOverPeriodOptionSection struct {

	// The spp discount cost.
	SppDiscountCost float64 `protobuf:"fixed64,1,opt,name=sppDiscountCost,proto3" json:"sppDiscountCost,omitempty"`
	// The spp discount cost Period-over-Period.
	// Represents a comparison of costs over a specified period of time.
	// currently, supported `Month-over-Month`
	SppDiscountCostPoP float64 `protobuf:"fixed64,2,opt,name=sppDiscountCostPoP,proto3" json:"sppDiscountCostPoP,omitempty"`
	// contains filtered or unexported fields
}

PeriodOverPeriodOptionSection resource definition.

func (*PeriodOverPeriodOptionSection) Descriptor deprecated added in v0.74.1

func (*PeriodOverPeriodOptionSection) Descriptor() ([]byte, []int)

Deprecated: Use PeriodOverPeriodOptionSection.ProtoReflect.Descriptor instead.

func (*PeriodOverPeriodOptionSection) GetSppDiscountCost added in v0.74.1

func (x *PeriodOverPeriodOptionSection) GetSppDiscountCost() float64

func (*PeriodOverPeriodOptionSection) GetSppDiscountCostPoP added in v0.74.1

func (x *PeriodOverPeriodOptionSection) GetSppDiscountCostPoP() float64

func (*PeriodOverPeriodOptionSection) ProtoMessage added in v0.74.1

func (*PeriodOverPeriodOptionSection) ProtoMessage()

func (*PeriodOverPeriodOptionSection) ProtoReflect added in v0.74.1

func (*PeriodOverPeriodOptionSection) Reset added in v0.74.1

func (x *PeriodOverPeriodOptionSection) Reset()

func (*PeriodOverPeriodOptionSection) String added in v0.74.1

type PeriodOverPeriodSection added in v0.74.1

type PeriodOverPeriodSection struct {

	// The invoice cost
	InvoiceCost float64 `protobuf:"fixed64,1,opt,name=invoiceCost,proto3" json:"invoiceCost,omitempty"`
	// The procurement cost
	ProcurementCost float64 `protobuf:"fixed64,2,opt,name=procurementCost,proto3" json:"procurementCost,omitempty"`
	// The profit cost
	ProfitCost float64 `protobuf:"fixed64,3,opt,name=profitCost,proto3" json:"profitCost,omitempty"`
	// The invoice cost Period-over-Period.
	// Represents a comparison of costs over a specified period of time.
	// currently, supported `Month-over-Month`
	InvoiceCostPoP float64 `protobuf:"fixed64,4,opt,name=invoiceCostPoP,proto3" json:"invoiceCostPoP,omitempty"`
	// The procurement cost Period-over-Period.
	// Represents a comparison of costs over a specified period of time.
	// currently, supported `Month-over-Month`
	ProcurementCostPoP float64 `protobuf:"fixed64,5,opt,name=procurementCostPoP,proto3" json:"procurementCostPoP,omitempty"`
	// The profit cost Period-over-Period.
	// Represents a comparison of costs over a specified period of time.
	// currently, supported `Month-over-Month`
	ProfitCostPoP float64 `protobuf:"fixed64,6,opt,name=profitCostPoP,proto3" json:"profitCostPoP,omitempty"`
	// The options cost Period-over-Period.
	Options *PeriodOverPeriodOptionSection `protobuf:"bytes,7,opt,name=options,proto3" json:"options,omitempty"`
	// contains filtered or unexported fields
}

PeriodOverPeriodSection resource definition.

func (*PeriodOverPeriodSection) Descriptor deprecated added in v0.74.1

func (*PeriodOverPeriodSection) Descriptor() ([]byte, []int)

Deprecated: Use PeriodOverPeriodSection.ProtoReflect.Descriptor instead.

func (*PeriodOverPeriodSection) GetInvoiceCost added in v0.74.1

func (x *PeriodOverPeriodSection) GetInvoiceCost() float64

func (*PeriodOverPeriodSection) GetInvoiceCostPoP added in v0.74.1

func (x *PeriodOverPeriodSection) GetInvoiceCostPoP() float64

func (*PeriodOverPeriodSection) GetOptions added in v0.74.1

func (*PeriodOverPeriodSection) GetProcurementCost added in v0.74.1

func (x *PeriodOverPeriodSection) GetProcurementCost() float64

func (*PeriodOverPeriodSection) GetProcurementCostPoP added in v0.74.1

func (x *PeriodOverPeriodSection) GetProcurementCostPoP() float64

func (*PeriodOverPeriodSection) GetProfitCost added in v0.74.1

func (x *PeriodOverPeriodSection) GetProfitCost() float64

func (*PeriodOverPeriodSection) GetProfitCostPoP added in v0.74.1

func (x *PeriodOverPeriodSection) GetProfitCostPoP() float64

func (*PeriodOverPeriodSection) ProtoMessage added in v0.74.1

func (*PeriodOverPeriodSection) ProtoMessage()

func (*PeriodOverPeriodSection) ProtoReflect added in v0.74.1

func (x *PeriodOverPeriodSection) ProtoReflect() protoreflect.Message

func (*PeriodOverPeriodSection) Reset added in v0.74.1

func (x *PeriodOverPeriodSection) Reset()

func (*PeriodOverPeriodSection) String added in v0.74.1

func (x *PeriodOverPeriodSection) String() string

type Service

type Service struct {

	// The service code.
	ServiceCode string `protobuf:"bytes,1,opt,name=serviceCode,proto3" json:"serviceCode,omitempty"`
	// The service name.
	ServiceName string `protobuf:"bytes,2,opt,name=serviceName,proto3" json:"serviceName,omitempty"`
	// contains filtered or unexported fields
}

Service resource definition. Services of each vendor available for Service Discounts.

func (*Service) Descriptor deprecated

func (*Service) Descriptor() ([]byte, []int)

Deprecated: Use Service.ProtoReflect.Descriptor instead.

func (*Service) GetServiceCode

func (x *Service) GetServiceCode() string

func (*Service) GetServiceName

func (x *Service) GetServiceName() string

func (*Service) ProtoMessage

func (*Service) ProtoMessage()

func (*Service) ProtoReflect

func (x *Service) ProtoReflect() protoreflect.Message

func (*Service) Reset

func (x *Service) Reset()

func (*Service) String

func (x *Service) String() string

type ServiceDiscountsExport added in v0.74.14

type ServiceDiscountsExport struct {

	// data is [blueapi.api.ripple.v1.ExportData]
	//
	// content. Base64 encoded value.
	// For example, content :“
	// Decoding this value, get “.
	//
	// downloadedRows. Downloaded content lines.
	//
	// totalRows.Total of content lines.
	Data *ExportData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

ServiceDiscountsExport resource definition.

func (*ServiceDiscountsExport) Descriptor deprecated added in v0.74.14

func (*ServiceDiscountsExport) Descriptor() ([]byte, []int)

Deprecated: Use ServiceDiscountsExport.ProtoReflect.Descriptor instead.

func (*ServiceDiscountsExport) GetData added in v0.74.14

func (x *ServiceDiscountsExport) GetData() *ExportData

func (*ServiceDiscountsExport) ProtoMessage added in v0.74.14

func (*ServiceDiscountsExport) ProtoMessage()

func (*ServiceDiscountsExport) ProtoReflect added in v0.74.14

func (x *ServiceDiscountsExport) ProtoReflect() protoreflect.Message

func (*ServiceDiscountsExport) Reset added in v0.74.14

func (x *ServiceDiscountsExport) Reset()

func (*ServiceDiscountsExport) String added in v0.74.14

func (x *ServiceDiscountsExport) String() string

type SupportPlan added in v0.74.80

type SupportPlan int32

Describes the overall config of a [blueapi.api.ripple.v1.SupportPlan].

const (
	// no_support
	SupportPlan_NO_SUPPORT SupportPlan = 0
	// aws_developer
	SupportPlan_AWS_DEVELOPER SupportPlan = 1
	// aws_business
	SupportPlan_AWS_BUSINESS SupportPlan = 2
	// aws_enterprise
	SupportPlan_AWS_ENTERPRISE SupportPlan = 3
	// aws_enterprise_on_ramp
	SupportPlan_AWS_ENTERPRISE_ON_RAMP SupportPlan = 4
)

func (SupportPlan) Descriptor added in v0.74.80

func (SupportPlan) Enum added in v0.74.80

func (x SupportPlan) Enum() *SupportPlan

func (SupportPlan) EnumDescriptor deprecated added in v0.74.80

func (SupportPlan) EnumDescriptor() ([]byte, []int)

Deprecated: Use SupportPlan.Descriptor instead.

func (SupportPlan) Number added in v0.74.80

func (x SupportPlan) Number() protoreflect.EnumNumber

func (SupportPlan) String added in v0.74.80

func (x SupportPlan) String() string

func (SupportPlan) Type added in v0.74.80

type ThirdProfitItemSection added in v0.74.1

type ThirdProfitItemSection struct {

	// The id.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// The name.
	Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// The profit cost.
	Profit float64 `protobuf:"fixed64,3,opt,name=profit,proto3" json:"profit,omitempty"`
	// contains filtered or unexported fields
}

ThirdProfitItemSection resource definition.

func (*ThirdProfitItemSection) Descriptor deprecated added in v0.74.1

func (*ThirdProfitItemSection) Descriptor() ([]byte, []int)

Deprecated: Use ThirdProfitItemSection.ProtoReflect.Descriptor instead.

func (*ThirdProfitItemSection) GetId added in v0.74.1

func (x *ThirdProfitItemSection) GetId() string

func (*ThirdProfitItemSection) GetName added in v0.74.1

func (x *ThirdProfitItemSection) GetName() string

func (*ThirdProfitItemSection) GetProfit added in v0.74.1

func (x *ThirdProfitItemSection) GetProfit() float64

func (*ThirdProfitItemSection) ProtoMessage added in v0.74.1

func (*ThirdProfitItemSection) ProtoMessage()

func (*ThirdProfitItemSection) ProtoReflect added in v0.74.1

func (x *ThirdProfitItemSection) ProtoReflect() protoreflect.Message

func (*ThirdProfitItemSection) Reset added in v0.74.1

func (x *ThirdProfitItemSection) Reset()

func (*ThirdProfitItemSection) String added in v0.74.1

func (x *ThirdProfitItemSection) String() string

type TotalDetailSection added in v0.74.1

type TotalDetailSection struct {

	// Cost(True unblended or Unblended) used for invoicing.
	TotalCost float64 `protobuf:"fixed64,1,opt,name=totalCost,proto3" json:"totalCost,omitempty"`
	// The spp discount cost.
	SppDiscount float64 `protobuf:"fixed64,2,opt,name=sppDiscount,proto3" json:"sppDiscount,omitempty"`
	// The third profit item cost.
	ThirdProfitItem float64 `protobuf:"fixed64,3,opt,name=thirdProfitItem,proto3" json:"thirdProfitItem,omitempty"`
	// contains filtered or unexported fields
}

TotalDetailSection resource definition.

func (*TotalDetailSection) Descriptor deprecated added in v0.74.1

func (*TotalDetailSection) Descriptor() ([]byte, []int)

Deprecated: Use TotalDetailSection.ProtoReflect.Descriptor instead.

func (*TotalDetailSection) GetSppDiscount added in v0.74.1

func (x *TotalDetailSection) GetSppDiscount() float64

func (*TotalDetailSection) GetThirdProfitItem added in v0.74.1

func (x *TotalDetailSection) GetThirdProfitItem() float64

func (*TotalDetailSection) GetTotalCost added in v0.74.60

func (x *TotalDetailSection) GetTotalCost() float64

func (*TotalDetailSection) ProtoMessage added in v0.74.1

func (*TotalDetailSection) ProtoMessage()

func (*TotalDetailSection) ProtoReflect added in v0.74.1

func (x *TotalDetailSection) ProtoReflect() protoreflect.Message

func (*TotalDetailSection) Reset added in v0.74.1

func (x *TotalDetailSection) Reset()

func (*TotalDetailSection) String added in v0.74.1

func (x *TotalDetailSection) String() string

type TotalSection added in v0.74.1

type TotalSection struct {

	// The id. id:TotalSection.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// The name. name:TotalSection.
	Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// The currency.
	Currency string `protobuf:"bytes,3,opt,name=currency,proto3" json:"currency,omitempty"`
	// The year-month. format: yyyymm
	YearMonth string `protobuf:"bytes,4,opt,name=yearMonth,proto3" json:"yearMonth,omitempty"`
	// The invoice cost.
	InvoiceCost float64 `protobuf:"fixed64,5,opt,name=invoiceCost,proto3" json:"invoiceCost,omitempty"`
	// The procurement cost.
	ProcurementCost float64 `protobuf:"fixed64,6,opt,name=procurementCost,proto3" json:"procurementCost,omitempty"`
	// The profit cost.
	ProfitCost float64 `protobuf:"fixed64,7,opt,name=profitCost,proto3" json:"profitCost,omitempty"`
	// The total detail.
	TotalDeital *TotalDetailSection `protobuf:"bytes,8,opt,name=totalDeital,proto3" json:"totalDeital,omitempty"`
	// The third profit item.
	ThirdProfitItem []*ThirdProfitItemSection `protobuf:"bytes,9,rep,name=thirdProfitItem,proto3" json:"thirdProfitItem,omitempty"`
	// The aws section.
	AwsSection *VendorTotalSection `protobuf:"bytes,10,opt,name=awsSection,proto3" json:"awsSection,omitempty"`
	// The azure section.
	AzureSection *VendorTotalSection `protobuf:"bytes,11,opt,name=azureSection,proto3" json:"azureSection,omitempty"`
	// The gcp section.
	GcpSection *VendorTotalSection `protobuf:"bytes,12,opt,name=gcpSection,proto3" json:"gcpSection,omitempty"`
	// contains filtered or unexported fields
}

TotalSection resource definition.

func (*TotalSection) Descriptor deprecated added in v0.74.1

func (*TotalSection) Descriptor() ([]byte, []int)

Deprecated: Use TotalSection.ProtoReflect.Descriptor instead.

func (*TotalSection) GetAwsSection added in v0.74.1

func (x *TotalSection) GetAwsSection() *VendorTotalSection

func (*TotalSection) GetAzureSection added in v0.74.1

func (x *TotalSection) GetAzureSection() *VendorTotalSection

func (*TotalSection) GetCurrency added in v0.74.1

func (x *TotalSection) GetCurrency() string

func (*TotalSection) GetGcpSection added in v0.74.1

func (x *TotalSection) GetGcpSection() *VendorTotalSection

func (*TotalSection) GetId added in v0.74.1

func (x *TotalSection) GetId() string

func (*TotalSection) GetInvoiceCost added in v0.74.1

func (x *TotalSection) GetInvoiceCost() float64

func (*TotalSection) GetName added in v0.74.1

func (x *TotalSection) GetName() string

func (*TotalSection) GetProcurementCost added in v0.74.1

func (x *TotalSection) GetProcurementCost() float64

func (*TotalSection) GetProfitCost added in v0.74.1

func (x *TotalSection) GetProfitCost() float64

func (*TotalSection) GetThirdProfitItem added in v0.74.1

func (x *TotalSection) GetThirdProfitItem() []*ThirdProfitItemSection

func (*TotalSection) GetTotalDeital added in v0.74.1

func (x *TotalSection) GetTotalDeital() *TotalDetailSection

func (*TotalSection) GetYearMonth added in v0.74.1

func (x *TotalSection) GetYearMonth() string

func (*TotalSection) ProtoMessage added in v0.74.1

func (*TotalSection) ProtoMessage()

func (*TotalSection) ProtoReflect added in v0.74.1

func (x *TotalSection) ProtoReflect() protoreflect.Message

func (*TotalSection) Reset added in v0.74.1

func (x *TotalSection) Reset()

func (*TotalSection) String added in v0.74.1

func (x *TotalSection) String() string

type VendorOverViewSection added in v0.74.1

type VendorOverViewSection struct {

	// The id. id:VendorOverViewSection.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// The name. name:VendorOverViewSection.
	Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// The currency.
	Currency string `protobuf:"bytes,3,opt,name=currency,proto3" json:"currency,omitempty"`
	// The invoice cost.
	InvoiceCost float64 `protobuf:"fixed64,4,opt,name=invoiceCost,proto3" json:"invoiceCost,omitempty"`
	// The procurement cost.
	ProcurementCost float64 `protobuf:"fixed64,5,opt,name=procurementCost,proto3" json:"procurementCost,omitempty"`
	// The profit cost.
	ProfitCost float64 `protobuf:"fixed64,6,opt,name=profitCost,proto3" json:"profitCost,omitempty"`
	// The options.
	Options *OverViewOptionSection `protobuf:"bytes,7,opt,name=options,proto3" json:"options,omitempty"`
	// The period over period.
	PeriodOverPeriod *PeriodOverPeriodSection `protobuf:"bytes,8,opt,name=periodOverPeriod,proto3" json:"periodOverPeriod,omitempty"`
	// contains filtered or unexported fields
}

VendorOverViewSection resource definition.

func (*VendorOverViewSection) Descriptor deprecated added in v0.74.1

func (*VendorOverViewSection) Descriptor() ([]byte, []int)

Deprecated: Use VendorOverViewSection.ProtoReflect.Descriptor instead.

func (*VendorOverViewSection) GetCurrency added in v0.74.1

func (x *VendorOverViewSection) GetCurrency() string

func (*VendorOverViewSection) GetId added in v0.74.1

func (x *VendorOverViewSection) GetId() string

func (*VendorOverViewSection) GetInvoiceCost added in v0.74.1

func (x *VendorOverViewSection) GetInvoiceCost() float64

func (*VendorOverViewSection) GetName added in v0.74.1

func (x *VendorOverViewSection) GetName() string

func (*VendorOverViewSection) GetOptions added in v0.74.1

func (*VendorOverViewSection) GetPeriodOverPeriod added in v0.74.1

func (x *VendorOverViewSection) GetPeriodOverPeriod() *PeriodOverPeriodSection

func (*VendorOverViewSection) GetProcurementCost added in v0.74.1

func (x *VendorOverViewSection) GetProcurementCost() float64

func (*VendorOverViewSection) GetProfitCost added in v0.74.1

func (x *VendorOverViewSection) GetProfitCost() float64

func (*VendorOverViewSection) ProtoMessage added in v0.74.1

func (*VendorOverViewSection) ProtoMessage()

func (*VendorOverViewSection) ProtoReflect added in v0.74.1

func (x *VendorOverViewSection) ProtoReflect() protoreflect.Message

func (*VendorOverViewSection) Reset added in v0.74.1

func (x *VendorOverViewSection) Reset()

func (*VendorOverViewSection) String added in v0.74.1

func (x *VendorOverViewSection) String() string

type VendorTotalSection added in v0.74.1

type VendorTotalSection struct {

	// The id. id:VendorTotalSection.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// The name. name:VendorTotalSection.
	Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// The currency.
	Currency string `protobuf:"bytes,3,opt,name=currency,proto3" json:"currency,omitempty"`
	// The year-month. format: yyyymm
	YearMonth string `protobuf:"bytes,4,opt,name=yearMonth,proto3" json:"yearMonth,omitempty"`
	// The invoice cost.
	InvoiceCost float64 `protobuf:"fixed64,5,opt,name=invoiceCost,proto3" json:"invoiceCost,omitempty"`
	// The procurement cost.
	ProcurementCost float64 `protobuf:"fixed64,6,opt,name=procurementCost,proto3" json:"procurementCost,omitempty"`
	// The profit cost.
	ProfitCost float64 `protobuf:"fixed64,7,opt,name=profitCost,proto3" json:"profitCost,omitempty"`
	// The total detail.
	TotalDeital *TotalDetailSection `protobuf:"bytes,8,opt,name=totalDeital,proto3" json:"totalDeital,omitempty"`
	// The yhird profit item.
	ThirdProfitItem []*ThirdProfitItemSection `protobuf:"bytes,9,rep,name=thirdProfitItem,proto3" json:"thirdProfitItem,omitempty"`
	// contains filtered or unexported fields
}

VendorTotalSection resource definition.

func (*VendorTotalSection) Descriptor deprecated added in v0.74.1

func (*VendorTotalSection) Descriptor() ([]byte, []int)

Deprecated: Use VendorTotalSection.ProtoReflect.Descriptor instead.

func (*VendorTotalSection) GetCurrency added in v0.74.1

func (x *VendorTotalSection) GetCurrency() string

func (*VendorTotalSection) GetId added in v0.74.1

func (x *VendorTotalSection) GetId() string

func (*VendorTotalSection) GetInvoiceCost added in v0.74.1

func (x *VendorTotalSection) GetInvoiceCost() float64

func (*VendorTotalSection) GetName added in v0.74.1

func (x *VendorTotalSection) GetName() string

func (*VendorTotalSection) GetProcurementCost added in v0.74.1

func (x *VendorTotalSection) GetProcurementCost() float64

func (*VendorTotalSection) GetProfitCost added in v0.74.1

func (x *VendorTotalSection) GetProfitCost() float64

func (*VendorTotalSection) GetThirdProfitItem added in v0.74.1

func (x *VendorTotalSection) GetThirdProfitItem() []*ThirdProfitItemSection

func (*VendorTotalSection) GetTotalDeital added in v0.74.1

func (x *VendorTotalSection) GetTotalDeital() *TotalDetailSection

func (*VendorTotalSection) GetYearMonth added in v0.74.1

func (x *VendorTotalSection) GetYearMonth() string

func (*VendorTotalSection) ProtoMessage added in v0.74.1

func (*VendorTotalSection) ProtoMessage()

func (*VendorTotalSection) ProtoReflect added in v0.74.1

func (x *VendorTotalSection) ProtoReflect() protoreflect.Message

func (*VendorTotalSection) Reset added in v0.74.1

func (x *VendorTotalSection) Reset()

func (*VendorTotalSection) String added in v0.74.1

func (x *VendorTotalSection) String() string

Jump to