flow

package
v0.76.21 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 19, 2025 License: Apache-2.0 Imports: 20 Imported by: 0

Documentation

Overview

Package flow is a reverse proxy.

It translates gRPC into RESTful JSON APIs.

Index

Constants

const (
	Flow_GetInfo_FullMethodName                          = "/blueapi.flow.v1.Flow/GetInfo"
	Flow_CreateSettings_FullMethodName                   = "/blueapi.flow.v1.Flow/CreateSettings"
	Flow_UpdateSettings_FullMethodName                   = "/blueapi.flow.v1.Flow/UpdateSettings"
	Flow_GetSettings_FullMethodName                      = "/blueapi.flow.v1.Flow/GetSettings"
	Flow_GetRecommendationDetails_FullMethodName         = "/blueapi.flow.v1.Flow/GetRecommendationDetails"
	Flow_GetCostExplorerAccessTemplateUrl_FullMethodName = "/blueapi.flow.v1.Flow/GetCostExplorerAccessTemplateUrl"
	Flow_GetSettingsHistory_FullMethodName               = "/blueapi.flow.v1.Flow/GetSettingsHistory"
	Flow_CreateCostExplorerAccess_FullMethodName         = "/blueapi.flow.v1.Flow/CreateCostExplorerAccess"
	Flow_GetDailyUsageCostDetails_FullMethodName         = "/blueapi.flow.v1.Flow/GetDailyUsageCostDetails"
)

Variables

var File_flow_v1_flow_proto protoreflect.FileDescriptor
var Flow_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "blueapi.flow.v1.Flow",
	HandlerType: (*FlowServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetInfo",
			Handler:    _Flow_GetInfo_Handler,
		},
		{
			MethodName: "CreateSettings",
			Handler:    _Flow_CreateSettings_Handler,
		},
		{
			MethodName: "UpdateSettings",
			Handler:    _Flow_UpdateSettings_Handler,
		},
		{
			MethodName: "GetSettings",
			Handler:    _Flow_GetSettings_Handler,
		},
		{
			MethodName: "GetRecommendationDetails",
			Handler:    _Flow_GetRecommendationDetails_Handler,
		},
		{
			MethodName: "GetCostExplorerAccessTemplateUrl",
			Handler:    _Flow_GetCostExplorerAccessTemplateUrl_Handler,
		},
		{
			MethodName: "GetSettingsHistory",
			Handler:    _Flow_GetSettingsHistory_Handler,
		},
		{
			MethodName: "CreateCostExplorerAccess",
			Handler:    _Flow_CreateCostExplorerAccess_Handler,
		},
		{
			MethodName: "GetDailyUsageCostDetails",
			Handler:    _Flow_GetDailyUsageCostDetails_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "flow/v1/flow.proto",
}

Flow_ServiceDesc is the grpc.ServiceDesc for Flow service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterFlowHandler

func RegisterFlowHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error

RegisterFlowHandler registers the http handlers for service Flow to "mux". The handlers forward requests to the grpc endpoint over "conn".

func RegisterFlowHandlerClient

func RegisterFlowHandlerClient(ctx context.Context, mux *runtime.ServeMux, client FlowClient) error

RegisterFlowHandlerClient registers the http handlers for service Flow to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "FlowClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "FlowClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "FlowClient" to call the correct interceptors. This client ignores the HTTP middlewares.

func RegisterFlowHandlerFromEndpoint

func RegisterFlowHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)

RegisterFlowHandlerFromEndpoint is same as RegisterFlowHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.

func RegisterFlowHandlerServer

func RegisterFlowHandlerServer(ctx context.Context, mux *runtime.ServeMux, server FlowServer) error

RegisterFlowHandlerServer registers the http handlers for service Flow to "mux". UnaryRPC :call FlowServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterFlowHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.

func RegisterFlowServer

func RegisterFlowServer(s grpc.ServiceRegistrar, srv FlowServer)

Types

type ClientOptions added in v0.74.52

type ClientOptions struct {
	Conn *conn.GrpcClientConn
}

ClientOptions represents the optional options to NewClient.

type CreateCostExplorerAccessRequest added in v0.75.97

type CreateCostExplorerAccessRequest struct {

	// Required. The target AWS account to validate.
	Target string `protobuf:"bytes,1,opt,name=target,proto3" json:"target,omitempty"`
	// contains filtered or unexported fields
}

Request message for the Flow.CreateCostExplorerAccess rpc. This endpoint only supports the 'apionly' template type.

func (*CreateCostExplorerAccessRequest) Descriptor deprecated added in v0.75.97

func (*CreateCostExplorerAccessRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreateCostExplorerAccessRequest.ProtoReflect.Descriptor instead.

func (*CreateCostExplorerAccessRequest) GetTarget added in v0.75.97

func (x *CreateCostExplorerAccessRequest) GetTarget() string

func (*CreateCostExplorerAccessRequest) ProtoMessage added in v0.75.97

func (*CreateCostExplorerAccessRequest) ProtoMessage()

func (*CreateCostExplorerAccessRequest) ProtoReflect added in v0.75.97

func (*CreateCostExplorerAccessRequest) Reset added in v0.75.97

func (*CreateCostExplorerAccessRequest) String added in v0.75.97

type CreateCostExplorerAccessResponse added in v0.75.97

type CreateCostExplorerAccessResponse struct {

	// The queried target account.
	Target string `protobuf:"bytes,1,opt,name=target,proto3" json:"target,omitempty"`
	// The role ARN that provides the cross-account access permissions.
	RoleArn string `protobuf:"bytes,2,opt,name=roleArn,proto3" json:"roleArn,omitempty"`
	// The external id for this role.
	ExternalId string `protobuf:"bytes,3,opt,name=externalId,proto3" json:"externalId,omitempty"`
	// The id of the CloudFormation stack deployed in the target account.
	StackId string `protobuf:"bytes,4,opt,name=stackId,proto3" json:"stackId,omitempty"`
	// The region where the stack is deployed.
	StackRegion string `protobuf:"bytes,5,opt,name=stackRegion,proto3" json:"stackRegion,omitempty"`
	// The latest template used to deploy the stack.
	TemplateUrl string `protobuf:"bytes,6,opt,name=templateUrl,proto3" json:"templateUrl,omitempty"`
	// This can be `latest`, `outdated`, or some error information.
	Status string `protobuf:"bytes,7,opt,name=status,proto3" json:"status,omitempty"`
	// The last updated timestamp, RFC3339 UTC.
	LastUpdated string `protobuf:"bytes,8,opt,name=lastUpdated,proto3" json:"lastUpdated,omitempty"`
	// contains filtered or unexported fields
}

Response message for the Flow.CreateCostExplorerAccess rpc.

func (*CreateCostExplorerAccessResponse) Descriptor deprecated added in v0.75.97

func (*CreateCostExplorerAccessResponse) Descriptor() ([]byte, []int)

Deprecated: Use CreateCostExplorerAccessResponse.ProtoReflect.Descriptor instead.

func (*CreateCostExplorerAccessResponse) GetExternalId added in v0.75.97

func (x *CreateCostExplorerAccessResponse) GetExternalId() string

func (*CreateCostExplorerAccessResponse) GetLastUpdated added in v0.75.97

func (x *CreateCostExplorerAccessResponse) GetLastUpdated() string

func (*CreateCostExplorerAccessResponse) GetRoleArn added in v0.75.97

func (x *CreateCostExplorerAccessResponse) GetRoleArn() string

func (*CreateCostExplorerAccessResponse) GetStackId added in v0.75.97

func (x *CreateCostExplorerAccessResponse) GetStackId() string

func (*CreateCostExplorerAccessResponse) GetStackRegion added in v0.75.97

func (x *CreateCostExplorerAccessResponse) GetStackRegion() string

func (*CreateCostExplorerAccessResponse) GetStatus added in v0.75.97

func (*CreateCostExplorerAccessResponse) GetTarget added in v0.75.97

func (*CreateCostExplorerAccessResponse) GetTemplateUrl added in v0.75.97

func (x *CreateCostExplorerAccessResponse) GetTemplateUrl() string

func (*CreateCostExplorerAccessResponse) ProtoMessage added in v0.75.97

func (*CreateCostExplorerAccessResponse) ProtoMessage()

func (*CreateCostExplorerAccessResponse) ProtoReflect added in v0.75.97

func (*CreateCostExplorerAccessResponse) Reset added in v0.75.97

func (*CreateCostExplorerAccessResponse) String added in v0.75.97

type CreateSettingsRequest added in v0.74.67

type CreateSettingsRequest struct {

	// Required. The id of the payer.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// Required. Account scope determines if the account is payer or linked account. Valid values are `payer` or `linked`.
	AccountScope string `protobuf:"bytes,2,opt,name=accountScope,proto3" json:"accountScope,omitempty"`
	// Required. Customization setting for SP. Valid values are `COMPUTE_SP` or `EC2_INSTANCE_SP`.
	Customization string `protobuf:"bytes,3,opt,name=customization,proto3" json:"customization,omitempty"`
	// Required. Term of the SP. Valid values are `ONE_YEAR` or `THREE_YEARS`.
	PlanTerm string `protobuf:"bytes,4,opt,name=planTerm,proto3" json:"planTerm,omitempty"`
	// Required. Payment option for the SP. Valid values are `ALL_UPFRONT`, `PARTIAL_UPFRONT`, or `NO_UPFRONT`.
	PaymentOption string `protobuf:"bytes,5,opt,name=paymentOption,proto3" json:"paymentOption,omitempty"`
	// Required. Lookback period for recommendation. Valid values are `SEVEN_DAYS`, `THIRTY_DAYS`, or `SIXTY_DAYS`.
	LookBackPeriod string `protobuf:"bytes,6,opt,name=lookBackPeriod,proto3" json:"lookBackPeriod,omitempty"`
	// Optional. If EC2 Instance SP is selected in Customization, request will include list of instance family
	InstanceFamily string `protobuf:"bytes,7,opt,name=instanceFamily,proto3" json:"instanceFamily,omitempty"`
	// Optional. Annual budget input for SP.
	AnnualBudget float64 `protobuf:"fixed64,8,opt,name=annualBudget,proto3" json:"annualBudget,omitempty"`
	// Optional. Purchase approval from the payer for the SP. Default value is `false`.
	Approval bool `protobuf:"varint,9,opt,name=approval,proto3" json:"approval,omitempty"`
	// Required. Payer account ID
	PayerId string `protobuf:"bytes,10,opt,name=payerId,proto3" json:"payerId,omitempty"`
	// contains filtered or unexported fields
}

Request message for the Flow.CreateSettings rpc.

func (*CreateSettingsRequest) Descriptor deprecated added in v0.74.67

func (*CreateSettingsRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreateSettingsRequest.ProtoReflect.Descriptor instead.

func (*CreateSettingsRequest) GetAccountScope added in v0.74.72

func (x *CreateSettingsRequest) GetAccountScope() string

func (*CreateSettingsRequest) GetAnnualBudget added in v0.74.67

func (x *CreateSettingsRequest) GetAnnualBudget() float64

func (*CreateSettingsRequest) GetApproval added in v0.74.67

func (x *CreateSettingsRequest) GetApproval() bool

func (*CreateSettingsRequest) GetCustomization added in v0.74.67

func (x *CreateSettingsRequest) GetCustomization() string

func (*CreateSettingsRequest) GetId added in v0.74.67

func (x *CreateSettingsRequest) GetId() string

func (*CreateSettingsRequest) GetInstanceFamily added in v0.74.67

func (x *CreateSettingsRequest) GetInstanceFamily() string

func (*CreateSettingsRequest) GetLookBackPeriod added in v0.74.67

func (x *CreateSettingsRequest) GetLookBackPeriod() string

func (*CreateSettingsRequest) GetPayerId added in v0.75.72

func (x *CreateSettingsRequest) GetPayerId() string

func (*CreateSettingsRequest) GetPaymentOption added in v0.74.67

func (x *CreateSettingsRequest) GetPaymentOption() string

func (*CreateSettingsRequest) GetPlanTerm added in v0.74.67

func (x *CreateSettingsRequest) GetPlanTerm() string

func (*CreateSettingsRequest) ProtoMessage added in v0.74.67

func (*CreateSettingsRequest) ProtoMessage()

func (*CreateSettingsRequest) ProtoReflect added in v0.74.67

func (x *CreateSettingsRequest) ProtoReflect() protoreflect.Message

func (*CreateSettingsRequest) Reset added in v0.74.67

func (x *CreateSettingsRequest) Reset()

func (*CreateSettingsRequest) String added in v0.74.67

func (x *CreateSettingsRequest) String() string

type CreateSettingsResponse added in v0.74.67

type CreateSettingsResponse struct {
	Response string `protobuf:"bytes,1,opt,name=response,proto3" json:"response,omitempty"`
	// contains filtered or unexported fields
}

Response message for the Flow.CreateSettings rpc.

func (*CreateSettingsResponse) Descriptor deprecated added in v0.74.67

func (*CreateSettingsResponse) Descriptor() ([]byte, []int)

Deprecated: Use CreateSettingsResponse.ProtoReflect.Descriptor instead.

func (*CreateSettingsResponse) GetResponse added in v0.74.67

func (x *CreateSettingsResponse) GetResponse() string

func (*CreateSettingsResponse) ProtoMessage added in v0.74.67

func (*CreateSettingsResponse) ProtoMessage()

func (*CreateSettingsResponse) ProtoReflect added in v0.74.67

func (x *CreateSettingsResponse) ProtoReflect() protoreflect.Message

func (*CreateSettingsResponse) Reset added in v0.74.67

func (x *CreateSettingsResponse) Reset()

func (*CreateSettingsResponse) String added in v0.74.67

func (x *CreateSettingsResponse) String() string

type FlowClient

type FlowClient interface {
	// For Testing Purposes Only.
	GetInfo(ctx context.Context, in *GetInfoRequest, opts ...grpc.CallOption) (*GetInfoResponse, error)
	// Creates a new settings configuration for the user.
	CreateSettings(ctx context.Context, in *CreateSettingsRequest, opts ...grpc.CallOption) (*CreateSettingsResponse, error)
	// Update the settings configuration for a user.
	UpdateSettings(ctx context.Context, in *UpdateSettingsRequest, opts ...grpc.CallOption) (*UpdateSettingsResponse, error)
	// Fetch previous settings for a user
	GetSettings(ctx context.Context, in *GetSettingsRequest, opts ...grpc.CallOption) (*GetSettingsResponse, error)
	// Fetch user savings plan details
	GetRecommendationDetails(ctx context.Context, in *GetRecommendationDetailsRequest, opts ...grpc.CallOption) (*GetRecommendationDetailsResponse, error)
	// Gets a CloudFormation launch URL for enabling read-only cross-account access to cost explorer information (API only).
	GetCostExplorerAccessTemplateUrl(ctx context.Context, in *GetCostExplorerAccessTemplateUrlRequest, opts ...grpc.CallOption) (*GetCostExplorerAccessTemplateUrlResponse, error)
	// Gets the settings configuration history for a user.
	GetSettingsHistory(ctx context.Context, in *GetSettingsHistoryRequest, opts ...grpc.CallOption) (*GetSettingsHistoryResponse, error)
	// Creates a default cross-account access role for cost explorer (API only).
	CreateCostExplorerAccess(ctx context.Context, in *CreateCostExplorerAccessRequest, opts ...grpc.CallOption) (*CreateCostExplorerAccessResponse, error)
	// Gets the daily cost and usage details.
	GetDailyUsageCostDetails(ctx context.Context, in *GetDailyUsageCostDetailsRequest, opts ...grpc.CallOption) (*GetDailyUsageCostDetailsResponse, error)
}

FlowClient is the client API for Flow service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Flow service definition.

func NewFlowClient

func NewFlowClient(cc grpc.ClientConnInterface) FlowClient

type FlowServer

type FlowServer interface {
	// For Testing Purposes Only.
	GetInfo(context.Context, *GetInfoRequest) (*GetInfoResponse, error)
	// Creates a new settings configuration for the user.
	CreateSettings(context.Context, *CreateSettingsRequest) (*CreateSettingsResponse, error)
	// Update the settings configuration for a user.
	UpdateSettings(context.Context, *UpdateSettingsRequest) (*UpdateSettingsResponse, error)
	// Fetch previous settings for a user
	GetSettings(context.Context, *GetSettingsRequest) (*GetSettingsResponse, error)
	// Fetch user savings plan details
	GetRecommendationDetails(context.Context, *GetRecommendationDetailsRequest) (*GetRecommendationDetailsResponse, error)
	// Gets a CloudFormation launch URL for enabling read-only cross-account access to cost explorer information (API only).
	GetCostExplorerAccessTemplateUrl(context.Context, *GetCostExplorerAccessTemplateUrlRequest) (*GetCostExplorerAccessTemplateUrlResponse, error)
	// Gets the settings configuration history for a user.
	GetSettingsHistory(context.Context, *GetSettingsHistoryRequest) (*GetSettingsHistoryResponse, error)
	// Creates a default cross-account access role for cost explorer (API only).
	CreateCostExplorerAccess(context.Context, *CreateCostExplorerAccessRequest) (*CreateCostExplorerAccessResponse, error)
	// Gets the daily cost and usage details.
	GetDailyUsageCostDetails(context.Context, *GetDailyUsageCostDetailsRequest) (*GetDailyUsageCostDetailsResponse, error)
	// contains filtered or unexported methods
}

FlowServer is the server API for Flow service. All implementations must embed UnimplementedFlowServer for forward compatibility

Flow service definition.

type GetCostExplorerAccessTemplateUrlRequest added in v0.75.94

type GetCostExplorerAccessTemplateUrlRequest struct {
	// contains filtered or unexported fields
}

Request message for the Flow.GetCostExplorerAccessTemplateUrl rpc. This endpoint only supports the 'apionly' template type.

func (*GetCostExplorerAccessTemplateUrlRequest) Descriptor deprecated added in v0.75.94

func (*GetCostExplorerAccessTemplateUrlRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetCostExplorerAccessTemplateUrlRequest.ProtoReflect.Descriptor instead.

func (*GetCostExplorerAccessTemplateUrlRequest) ProtoMessage added in v0.75.94

func (*GetCostExplorerAccessTemplateUrlRequest) ProtoReflect added in v0.75.94

func (*GetCostExplorerAccessTemplateUrlRequest) Reset added in v0.75.94

func (*GetCostExplorerAccessTemplateUrlRequest) String added in v0.75.94

type GetCostExplorerAccessTemplateUrlResponse added in v0.75.94

type GetCostExplorerAccessTemplateUrlResponse struct {

	// The CloudFormation launch url. Open it in your browser.
	LaunchUrl string `protobuf:"bytes,1,opt,name=launchUrl,proto3" json:"launchUrl,omitempty"`
	// The latest CloudFormation template. The version is included in the filename.
	TemplateUrl string `protobuf:"bytes,2,opt,name=templateUrl,proto3" json:"templateUrl,omitempty"`
	// The default stack name used. Can be modified.
	StackName string `protobuf:"bytes,3,opt,name=stackName,proto3" json:"stackName,omitempty"`
	// The AWS account that will receive the access. Do not change.
	Principal string `protobuf:"bytes,4,opt,name=principal,proto3" json:"principal,omitempty"`
	// The external id for this role. Do not change.
	ExternalId string `protobuf:"bytes,5,opt,name=externalId,proto3" json:"externalId,omitempty"`
	// contains filtered or unexported fields
}

Response message for the Flow.GetCostExplorerAccessTemplateUrl rpc.

func (*GetCostExplorerAccessTemplateUrlResponse) Descriptor deprecated added in v0.75.94

func (*GetCostExplorerAccessTemplateUrlResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetCostExplorerAccessTemplateUrlResponse.ProtoReflect.Descriptor instead.

func (*GetCostExplorerAccessTemplateUrlResponse) GetExternalId added in v0.75.94

func (*GetCostExplorerAccessTemplateUrlResponse) GetLaunchUrl added in v0.75.94

func (*GetCostExplorerAccessTemplateUrlResponse) GetPrincipal added in v0.75.94

func (*GetCostExplorerAccessTemplateUrlResponse) GetStackName added in v0.75.94

func (*GetCostExplorerAccessTemplateUrlResponse) GetTemplateUrl added in v0.75.94

func (*GetCostExplorerAccessTemplateUrlResponse) ProtoMessage added in v0.75.94

func (*GetCostExplorerAccessTemplateUrlResponse) ProtoReflect added in v0.75.94

func (*GetCostExplorerAccessTemplateUrlResponse) Reset added in v0.75.94

func (*GetCostExplorerAccessTemplateUrlResponse) String added in v0.75.94

type GetDailyUsageCostDetailsRequest added in v0.76.12

type GetDailyUsageCostDetailsRequest struct {

	// Required. The id of the payer to fetch savings plan details for.
	PayerId string `protobuf:"bytes,1,opt,name=payerId,proto3" json:"payerId,omitempty"`
	// Required. The start date of the range for the savings plan details.
	StartDate string `protobuf:"bytes,2,opt,name=startDate,proto3" json:"startDate,omitempty"`
	// Required. The end date of the range for the savings plan details.
	EndDate string `protobuf:"bytes,3,opt,name=endDate,proto3" json:"endDate,omitempty"`
	// contains filtered or unexported fields
}

Request message for the Flow.GetDailyUsageCostDetailsRequest rpc.

func (*GetDailyUsageCostDetailsRequest) Descriptor deprecated added in v0.76.12

func (*GetDailyUsageCostDetailsRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetDailyUsageCostDetailsRequest.ProtoReflect.Descriptor instead.

func (*GetDailyUsageCostDetailsRequest) GetEndDate added in v0.76.12

func (x *GetDailyUsageCostDetailsRequest) GetEndDate() string

func (*GetDailyUsageCostDetailsRequest) GetPayerId added in v0.76.12

func (x *GetDailyUsageCostDetailsRequest) GetPayerId() string

func (*GetDailyUsageCostDetailsRequest) GetStartDate added in v0.76.12

func (x *GetDailyUsageCostDetailsRequest) GetStartDate() string

func (*GetDailyUsageCostDetailsRequest) ProtoMessage added in v0.76.12

func (*GetDailyUsageCostDetailsRequest) ProtoMessage()

func (*GetDailyUsageCostDetailsRequest) ProtoReflect added in v0.76.12

func (*GetDailyUsageCostDetailsRequest) Reset added in v0.76.12

func (*GetDailyUsageCostDetailsRequest) String added in v0.76.12

type GetDailyUsageCostDetailsResponse added in v0.76.12

type GetDailyUsageCostDetailsResponse struct {

	// The payer account ID for which the savings plan details are fetched.
	PayerId string `protobuf:"bytes,1,opt,name=payerId,proto3" json:"payerId,omitempty"`
	// Actual monthly on-demand cost for the payer account.
	MonthlyOnDemandCost float64 `protobuf:"fixed64,2,opt,name=monthlyOnDemandCost,proto3" json:"monthlyOnDemandCost,omitempty"`
	// Actual monthly effective cost after applying Savings Plans.
	MonthlyEffectiveCost float64 `protobuf:"fixed64,3,opt,name=monthlyEffectiveCost,proto3" json:"monthlyEffectiveCost,omitempty"`
	// Actual total monthly savings from Savings Plan usage.
	MonthlyTotalSavings float64 `protobuf:"fixed64,4,opt,name=monthlyTotalSavings,proto3" json:"monthlyTotalSavings,omitempty"`
	// Purchased Savings Plan details for the payer account.
	SpDetails *SpDetails `protobuf:"bytes,5,opt,name=spDetails,proto3" json:"spDetails,omitempty"`
	// Daily Savings Plan usage and cost details
	UsageCostDetails []*UsageCostDetails `protobuf:"bytes,6,rep,name=usageCostDetails,proto3" json:"usageCostDetails,omitempty"`
	// contains filtered or unexported fields
}

Response message for the Flow.GetDailyUsageCostDetailsResponse rpc.

func (*GetDailyUsageCostDetailsResponse) Descriptor deprecated added in v0.76.12

func (*GetDailyUsageCostDetailsResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetDailyUsageCostDetailsResponse.ProtoReflect.Descriptor instead.

func (*GetDailyUsageCostDetailsResponse) GetMonthlyEffectiveCost added in v0.76.12

func (x *GetDailyUsageCostDetailsResponse) GetMonthlyEffectiveCost() float64

func (*GetDailyUsageCostDetailsResponse) GetMonthlyOnDemandCost added in v0.76.12

func (x *GetDailyUsageCostDetailsResponse) GetMonthlyOnDemandCost() float64

func (*GetDailyUsageCostDetailsResponse) GetMonthlyTotalSavings added in v0.76.12

func (x *GetDailyUsageCostDetailsResponse) GetMonthlyTotalSavings() float64

func (*GetDailyUsageCostDetailsResponse) GetPayerId added in v0.76.12

func (x *GetDailyUsageCostDetailsResponse) GetPayerId() string

func (*GetDailyUsageCostDetailsResponse) GetSpDetails added in v0.76.12

func (x *GetDailyUsageCostDetailsResponse) GetSpDetails() *SpDetails

func (*GetDailyUsageCostDetailsResponse) GetUsageCostDetails added in v0.76.12

func (x *GetDailyUsageCostDetailsResponse) GetUsageCostDetails() []*UsageCostDetails

func (*GetDailyUsageCostDetailsResponse) ProtoMessage added in v0.76.12

func (*GetDailyUsageCostDetailsResponse) ProtoMessage()

func (*GetDailyUsageCostDetailsResponse) ProtoReflect added in v0.76.12

func (*GetDailyUsageCostDetailsResponse) Reset added in v0.76.12

func (*GetDailyUsageCostDetailsResponse) String added in v0.76.12

type GetInfoRequest

type GetInfoRequest struct {
	// contains filtered or unexported fields
}

Request message for the Flow.GetInfo rpc.

func (*GetInfoRequest) Descriptor deprecated

func (*GetInfoRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetInfoRequest.ProtoReflect.Descriptor instead.

func (*GetInfoRequest) ProtoMessage

func (*GetInfoRequest) ProtoMessage()

func (*GetInfoRequest) ProtoReflect

func (x *GetInfoRequest) ProtoReflect() protoreflect.Message

func (*GetInfoRequest) Reset

func (x *GetInfoRequest) Reset()

func (*GetInfoRequest) String

func (x *GetInfoRequest) String() string

type GetInfoResponse

type GetInfoResponse struct {
	Response string `protobuf:"bytes,1,opt,name=response,proto3" json:"response,omitempty"`
	// contains filtered or unexported fields
}

Response message for the Flow.GetInfo rpc.

func (*GetInfoResponse) Descriptor deprecated

func (*GetInfoResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetInfoResponse.ProtoReflect.Descriptor instead.

func (*GetInfoResponse) GetResponse

func (x *GetInfoResponse) GetResponse() string

func (*GetInfoResponse) ProtoMessage

func (*GetInfoResponse) ProtoMessage()

func (*GetInfoResponse) ProtoReflect

func (x *GetInfoResponse) ProtoReflect() protoreflect.Message

func (*GetInfoResponse) Reset

func (x *GetInfoResponse) Reset()

func (*GetInfoResponse) String

func (x *GetInfoResponse) String() string

type GetRecommendationDetailsRequest added in v0.75.86

type GetRecommendationDetailsRequest struct {

	// Required. The id of the payer to fetch recommendation details for.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*GetRecommendationDetailsRequest) Descriptor deprecated added in v0.75.86

func (*GetRecommendationDetailsRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetRecommendationDetailsRequest.ProtoReflect.Descriptor instead.

func (*GetRecommendationDetailsRequest) GetId added in v0.75.86

func (*GetRecommendationDetailsRequest) ProtoMessage added in v0.75.86

func (*GetRecommendationDetailsRequest) ProtoMessage()

func (*GetRecommendationDetailsRequest) ProtoReflect added in v0.75.86

func (*GetRecommendationDetailsRequest) Reset added in v0.75.86

func (*GetRecommendationDetailsRequest) String added in v0.75.86

type GetRecommendationDetailsResponse added in v0.75.86

type GetRecommendationDetailsResponse struct {

	// Unique ID of the recommendation details entry
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// Projected monthly on-demand spend without Savings Plans, normalized from lookback period
	CurrentMonthlyOnDemandSpend float64 `protobuf:"fixed64,2,opt,name=currentMonthlyOnDemandSpend,proto3" json:"currentMonthlyOnDemandSpend,omitempty"`
	// Projected total monthly spend after applying the recommended Savings Plan, normalized
	EstimatedMonthlySpend float64 `protobuf:"fixed64,3,opt,name=estimatedMonthlySpend,proto3" json:"estimatedMonthlySpend,omitempty"`
	// Difference between on-demand and post-SP spend, computed from normalized values
	EstimatedMonthlySavingsDerived float64 `protobuf:"fixed64,4,opt,name=estimatedMonthlySavingsDerived,proto3" json:"estimatedMonthlySavingsDerived,omitempty"`
	// Total current daily cost from usage, before applying any SP recommendation (Derived)
	TotalDailyCost float64 `protobuf:"fixed64,5,opt,name=totalDailyCost,proto3" json:"totalDailyCost,omitempty"`
	// Current Savings Plan commitment applied
	CurrentSPCommitment float64 `protobuf:"fixed64,6,opt,name=currentSPCommitment,proto3" json:"currentSPCommitment,omitempty"`
	// Estimated daily on-demand cost without any Savings Plans
	EstimatedOnDemandCost float64 `protobuf:"fixed64,7,opt,name=estimatedOnDemandCost,proto3" json:"estimatedOnDemandCost,omitempty"`
	// Suggested hourly commitment to purchase in USD
	HourlyCommitment float64 `protobuf:"fixed64,8,opt,name=hourlyCommitment,proto3" json:"hourlyCommitment,omitempty"`
	// Projected monthly savings from the recommended savings plan
	EstimatedMonthlySavings float64 `protobuf:"fixed64,9,opt,name=estimatedMonthlySavings,proto3" json:"estimatedMonthlySavings,omitempty"`
	// Percentage of potential savings from savings plan
	EstimatedSavings float64 `protobuf:"fixed64,10,opt,name=estimatedSavings,proto3" json:"estimatedSavings,omitempty"`
	// Customization setting for savings plan
	RecommendationLevel string `protobuf:"bytes,11,opt,name=recommendationLevel,proto3" json:"recommendationLevel,omitempty"`
	// Savings plan type.
	PlanType string `protobuf:"bytes,12,opt,name=planType,proto3" json:"planType,omitempty"`
	// Savings plan duration.
	PlanTerm string `protobuf:"bytes,13,opt,name=planTerm,proto3" json:"planTerm,omitempty"`
	// Savings plan payment option.
	PaymentOption string `protobuf:"bytes,14,opt,name=paymentOption,proto3" json:"paymentOption,omitempty"`
	// Savings plan lookback period used for analysis.
	LookBackPeriod string `protobuf:"bytes,15,opt,name=lookBackPeriod,proto3" json:"lookBackPeriod,omitempty"`
	// Savings plan estimated return on investment.
	EstimatedROI float64 `protobuf:"fixed64,16,opt,name=estimatedROI,proto3" json:"estimatedROI,omitempty"`
	// Savings plan total projected cost over the term.
	EstimatedSPCost float64 `protobuf:"fixed64,17,opt,name=estimatedSPCost,proto3" json:"estimatedSPCost,omitempty"`
	// Savings plan estimated total cost and including on-demand.
	EstimatedTotalCost float64 `protobuf:"fixed64,18,opt,name=estimatedTotalCost,proto3" json:"estimatedTotalCost,omitempty"`
	// Savings plan last updated
	LastUpdated string `protobuf:"bytes,19,opt,name=lastUpdated,proto3" json:"lastUpdated,omitempty"`
	// contains filtered or unexported fields
}

func (*GetRecommendationDetailsResponse) Descriptor deprecated added in v0.75.86

func (*GetRecommendationDetailsResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetRecommendationDetailsResponse.ProtoReflect.Descriptor instead.

func (*GetRecommendationDetailsResponse) GetCurrentMonthlyOnDemandSpend added in v0.75.89

func (x *GetRecommendationDetailsResponse) GetCurrentMonthlyOnDemandSpend() float64

func (*GetRecommendationDetailsResponse) GetCurrentSPCommitment added in v0.75.86

func (x *GetRecommendationDetailsResponse) GetCurrentSPCommitment() float64

func (*GetRecommendationDetailsResponse) GetEstimatedMonthlySavings added in v0.75.86

func (x *GetRecommendationDetailsResponse) GetEstimatedMonthlySavings() float64

func (*GetRecommendationDetailsResponse) GetEstimatedMonthlySavingsDerived added in v0.75.89

func (x *GetRecommendationDetailsResponse) GetEstimatedMonthlySavingsDerived() float64

func (*GetRecommendationDetailsResponse) GetEstimatedMonthlySpend added in v0.75.89

func (x *GetRecommendationDetailsResponse) GetEstimatedMonthlySpend() float64

func (*GetRecommendationDetailsResponse) GetEstimatedOnDemandCost added in v0.75.86

func (x *GetRecommendationDetailsResponse) GetEstimatedOnDemandCost() float64

func (*GetRecommendationDetailsResponse) GetEstimatedROI added in v0.75.86

func (x *GetRecommendationDetailsResponse) GetEstimatedROI() float64

func (*GetRecommendationDetailsResponse) GetEstimatedSPCost added in v0.75.86

func (x *GetRecommendationDetailsResponse) GetEstimatedSPCost() float64

func (*GetRecommendationDetailsResponse) GetEstimatedSavings added in v0.75.86

func (x *GetRecommendationDetailsResponse) GetEstimatedSavings() float64

func (*GetRecommendationDetailsResponse) GetEstimatedTotalCost added in v0.75.86

func (x *GetRecommendationDetailsResponse) GetEstimatedTotalCost() float64

func (*GetRecommendationDetailsResponse) GetHourlyCommitment added in v0.75.86

func (x *GetRecommendationDetailsResponse) GetHourlyCommitment() float64

func (*GetRecommendationDetailsResponse) GetId added in v0.75.86

func (*GetRecommendationDetailsResponse) GetLastUpdated added in v0.75.86

func (x *GetRecommendationDetailsResponse) GetLastUpdated() string

func (*GetRecommendationDetailsResponse) GetLookBackPeriod added in v0.75.86

func (x *GetRecommendationDetailsResponse) GetLookBackPeriod() string

func (*GetRecommendationDetailsResponse) GetPaymentOption added in v0.75.86

func (x *GetRecommendationDetailsResponse) GetPaymentOption() string

func (*GetRecommendationDetailsResponse) GetPlanTerm added in v0.75.86

func (x *GetRecommendationDetailsResponse) GetPlanTerm() string

func (*GetRecommendationDetailsResponse) GetPlanType added in v0.75.86

func (x *GetRecommendationDetailsResponse) GetPlanType() string

func (*GetRecommendationDetailsResponse) GetRecommendationLevel added in v0.75.86

func (x *GetRecommendationDetailsResponse) GetRecommendationLevel() string

func (*GetRecommendationDetailsResponse) GetTotalDailyCost added in v0.75.86

func (x *GetRecommendationDetailsResponse) GetTotalDailyCost() float64

func (*GetRecommendationDetailsResponse) ProtoMessage added in v0.75.86

func (*GetRecommendationDetailsResponse) ProtoMessage()

func (*GetRecommendationDetailsResponse) ProtoReflect added in v0.75.86

func (*GetRecommendationDetailsResponse) Reset added in v0.75.86

func (*GetRecommendationDetailsResponse) String added in v0.75.86

type GetSettingsHistoryRequest added in v0.75.96

type GetSettingsHistoryRequest struct {

	// Required. The id of the payer to fetch settings history for.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

Request message for the Flow.GetSettingsHistory rpc.

func (*GetSettingsHistoryRequest) Descriptor deprecated added in v0.75.96

func (*GetSettingsHistoryRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetSettingsHistoryRequest.ProtoReflect.Descriptor instead.

func (*GetSettingsHistoryRequest) GetId added in v0.75.96

func (x *GetSettingsHistoryRequest) GetId() string

func (*GetSettingsHistoryRequest) ProtoMessage added in v0.75.96

func (*GetSettingsHistoryRequest) ProtoMessage()

func (*GetSettingsHistoryRequest) ProtoReflect added in v0.75.96

func (*GetSettingsHistoryRequest) Reset added in v0.75.96

func (x *GetSettingsHistoryRequest) Reset()

func (*GetSettingsHistoryRequest) String added in v0.75.96

func (x *GetSettingsHistoryRequest) String() string

type GetSettingsHistoryResponse added in v0.75.96

type GetSettingsHistoryResponse struct {
	SettingsHistory []*SettingsHistory `protobuf:"bytes,1,rep,name=settingsHistory,proto3" json:"settingsHistory,omitempty"`
	// contains filtered or unexported fields
}

Response message for the Flow.GetSettingsHistory rpc.

func (*GetSettingsHistoryResponse) Descriptor deprecated added in v0.75.96

func (*GetSettingsHistoryResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetSettingsHistoryResponse.ProtoReflect.Descriptor instead.

func (*GetSettingsHistoryResponse) GetSettingsHistory added in v0.75.96

func (x *GetSettingsHistoryResponse) GetSettingsHistory() []*SettingsHistory

func (*GetSettingsHistoryResponse) ProtoMessage added in v0.75.96

func (*GetSettingsHistoryResponse) ProtoMessage()

func (*GetSettingsHistoryResponse) ProtoReflect added in v0.75.96

func (*GetSettingsHistoryResponse) Reset added in v0.75.96

func (x *GetSettingsHistoryResponse) Reset()

func (*GetSettingsHistoryResponse) String added in v0.75.96

func (x *GetSettingsHistoryResponse) String() string

type GetSettingsRequest added in v0.75.61

type GetSettingsRequest struct {

	// Required. The id of the payer to fetch settings for.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

Request message for fetching previous settings configuration of a user.

func (*GetSettingsRequest) Descriptor deprecated added in v0.75.61

func (*GetSettingsRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetSettingsRequest.ProtoReflect.Descriptor instead.

func (*GetSettingsRequest) GetId added in v0.75.61

func (x *GetSettingsRequest) GetId() string

func (*GetSettingsRequest) ProtoMessage added in v0.75.61

func (*GetSettingsRequest) ProtoMessage()

func (*GetSettingsRequest) ProtoReflect added in v0.75.61

func (x *GetSettingsRequest) ProtoReflect() protoreflect.Message

func (*GetSettingsRequest) Reset added in v0.75.61

func (x *GetSettingsRequest) Reset()

func (*GetSettingsRequest) String added in v0.75.61

func (x *GetSettingsRequest) String() string

type GetSettingsResponse added in v0.75.61

type GetSettingsResponse struct {
	Id             string  `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	AccountScope   string  `protobuf:"bytes,2,opt,name=accountScope,proto3" json:"accountScope,omitempty"`
	Customization  string  `protobuf:"bytes,3,opt,name=customization,proto3" json:"customization,omitempty"`
	PlanTerm       string  `protobuf:"bytes,4,opt,name=planTerm,proto3" json:"planTerm,omitempty"`
	PaymentOption  string  `protobuf:"bytes,5,opt,name=paymentOption,proto3" json:"paymentOption,omitempty"`
	LookBackPeriod string  `protobuf:"bytes,6,opt,name=lookBackPeriod,proto3" json:"lookBackPeriod,omitempty"`
	InstanceFamily string  `protobuf:"bytes,7,opt,name=instanceFamily,proto3" json:"instanceFamily,omitempty"`
	AnnualBudget   float64 `protobuf:"fixed64,8,opt,name=annualBudget,proto3" json:"annualBudget,omitempty"`
	Approval       bool    `protobuf:"varint,9,opt,name=approval,proto3" json:"approval,omitempty"`
	LastUpdated    string  `protobuf:"bytes,10,opt,name=lastUpdated,proto3" json:"lastUpdated,omitempty"`
	PayerId        string  `protobuf:"bytes,11,opt,name=payerId,proto3" json:"payerId,omitempty"`
	// contains filtered or unexported fields
}

Response message for fetching previous settings configuration of a user.

func (*GetSettingsResponse) Descriptor deprecated added in v0.75.61

func (*GetSettingsResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetSettingsResponse.ProtoReflect.Descriptor instead.

func (*GetSettingsResponse) GetAccountScope added in v0.75.61

func (x *GetSettingsResponse) GetAccountScope() string

func (*GetSettingsResponse) GetAnnualBudget added in v0.75.61

func (x *GetSettingsResponse) GetAnnualBudget() float64

func (*GetSettingsResponse) GetApproval added in v0.75.61

func (x *GetSettingsResponse) GetApproval() bool

func (*GetSettingsResponse) GetCustomization added in v0.75.61

func (x *GetSettingsResponse) GetCustomization() string

func (*GetSettingsResponse) GetId added in v0.75.61

func (x *GetSettingsResponse) GetId() string

func (*GetSettingsResponse) GetInstanceFamily added in v0.75.61

func (x *GetSettingsResponse) GetInstanceFamily() string

func (*GetSettingsResponse) GetLastUpdated added in v0.75.61

func (x *GetSettingsResponse) GetLastUpdated() string

func (*GetSettingsResponse) GetLookBackPeriod added in v0.75.61

func (x *GetSettingsResponse) GetLookBackPeriod() string

func (*GetSettingsResponse) GetPayerId added in v0.75.72

func (x *GetSettingsResponse) GetPayerId() string

func (*GetSettingsResponse) GetPaymentOption added in v0.75.61

func (x *GetSettingsResponse) GetPaymentOption() string

func (*GetSettingsResponse) GetPlanTerm added in v0.75.61

func (x *GetSettingsResponse) GetPlanTerm() string

func (*GetSettingsResponse) ProtoMessage added in v0.75.61

func (*GetSettingsResponse) ProtoMessage()

func (*GetSettingsResponse) ProtoReflect added in v0.75.61

func (x *GetSettingsResponse) ProtoReflect() protoreflect.Message

func (*GetSettingsResponse) Reset added in v0.75.61

func (x *GetSettingsResponse) Reset()

func (*GetSettingsResponse) String added in v0.75.61

func (x *GetSettingsResponse) String() string

type GrpcClient added in v0.74.52

type GrpcClient struct {
	FlowClient
	// contains filtered or unexported fields
}

func NewClient added in v0.74.52

func NewClient(ctx context.Context, opts ...*ClientOptions) (*GrpcClient, error)

NewClient returns a client connection to the 'flow' service.

func (*GrpcClient) Close added in v0.74.52

func (c *GrpcClient) Close()

type SettingsHistory added in v0.75.96

type SettingsHistory struct {

	// Payer account ID.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// Account scope determines if the account is payer or linked account.
	AccountScope string `protobuf:"bytes,2,opt,name=accountScope,proto3" json:"accountScope,omitempty"`
	// Customization setting for SP.
	Customization string `protobuf:"bytes,3,opt,name=customization,proto3" json:"customization,omitempty"`
	// Term of the SP.
	PlanTerm string `protobuf:"bytes,4,opt,name=planTerm,proto3" json:"planTerm,omitempty"`
	// Payment option for the SP.
	PaymentOption string `protobuf:"bytes,5,opt,name=paymentOption,proto3" json:"paymentOption,omitempty"`
	// Lookback period for recommendation.
	LookBackPeriod string `protobuf:"bytes,6,opt,name=lookBackPeriod,proto3" json:"lookBackPeriod,omitempty"`
	// If EC2 Instance SP is selected in Customization, request will include list of instance family
	InstanceFamily string `protobuf:"bytes,7,opt,name=instanceFamily,proto3" json:"instanceFamily,omitempty"`
	// Annual budget input for SP.
	AnnualBudget float64 `protobuf:"fixed64,8,opt,name=annualBudget,proto3" json:"annualBudget,omitempty"`
	// Purchase approval from the payer for the SP.
	Approval bool `protobuf:"varint,9,opt,name=approval,proto3" json:"approval,omitempty"`
	// Last updated timestamp of the settings configuration.
	LastUpdated string `protobuf:"bytes,10,opt,name=lastUpdated,proto3" json:"lastUpdated,omitempty"`
	// contains filtered or unexported fields
}

Settings history message.

func (*SettingsHistory) Descriptor deprecated added in v0.75.96

func (*SettingsHistory) Descriptor() ([]byte, []int)

Deprecated: Use SettingsHistory.ProtoReflect.Descriptor instead.

func (*SettingsHistory) GetAccountScope added in v0.75.96

func (x *SettingsHistory) GetAccountScope() string

func (*SettingsHistory) GetAnnualBudget added in v0.75.96

func (x *SettingsHistory) GetAnnualBudget() float64

func (*SettingsHistory) GetApproval added in v0.75.96

func (x *SettingsHistory) GetApproval() bool

func (*SettingsHistory) GetCustomization added in v0.75.96

func (x *SettingsHistory) GetCustomization() string

func (*SettingsHistory) GetId added in v0.75.96

func (x *SettingsHistory) GetId() string

func (*SettingsHistory) GetInstanceFamily added in v0.75.96

func (x *SettingsHistory) GetInstanceFamily() string

func (*SettingsHistory) GetLastUpdated added in v0.75.96

func (x *SettingsHistory) GetLastUpdated() string

func (*SettingsHistory) GetLookBackPeriod added in v0.75.96

func (x *SettingsHistory) GetLookBackPeriod() string

func (*SettingsHistory) GetPaymentOption added in v0.75.96

func (x *SettingsHistory) GetPaymentOption() string

func (*SettingsHistory) GetPlanTerm added in v0.75.96

func (x *SettingsHistory) GetPlanTerm() string

func (*SettingsHistory) ProtoMessage added in v0.75.96

func (*SettingsHistory) ProtoMessage()

func (*SettingsHistory) ProtoReflect added in v0.75.96

func (x *SettingsHistory) ProtoReflect() protoreflect.Message

func (*SettingsHistory) Reset added in v0.75.96

func (x *SettingsHistory) Reset()

func (*SettingsHistory) String added in v0.75.96

func (x *SettingsHistory) String() string

type SpDetails added in v0.76.20

type SpDetails struct {

	// The payer account ID for which the savings plan details are fetched.
	PayerId string `protobuf:"bytes,1,opt,name=payerId,proto3" json:"payerId,omitempty"`
	// The savings plan type, e.g., `Compute`, `Ec2`.
	SavingsPlanType string `protobuf:"bytes,2,opt,name=savingsPlanType,proto3" json:"savingsPlanType,omitempty"`
	// The current state of the savings plan, e.g., `ACTIVE`, `EXPIRED`, `PENDING`.
	State string `protobuf:"bytes,3,opt,name=state,proto3" json:"state,omitempty"`
	// The start time of the savings plan.
	StartTime string `protobuf:"bytes,4,opt,name=startTime,proto3" json:"startTime,omitempty"`
	// The end time of the savings plan.
	EndTime string `protobuf:"bytes,5,opt,name=endTime,proto3" json:"endTime,omitempty"`
	// The date until which the savings plan is returnable, if applicable.
	ReturnableUntil string `protobuf:"bytes,6,opt,name=returnableUntil,proto3" json:"returnableUntil,omitempty"`
	// The currency in which the savings plan is priced, e.g., `USD`.
	Currency string `protobuf:"bytes,7,opt,name=currency,proto3" json:"currency,omitempty"`
	// The commitment amount per hour for the savings plan in USD.
	Commitment float64 `protobuf:"fixed64,8,opt,name=commitment,proto3" json:"commitment,omitempty"`
	// A description of the savings plan, including details like the instance family and payment option.
	Description string `protobuf:"bytes,9,opt,name=description,proto3" json:"description,omitempty"`
	// The payment option for the savings plan, e.g., `All Upfront`, `Partial Upfront`, `No Upfront`.
	PaymentOption string `protobuf:"bytes,10,opt,name=paymentOption,proto3" json:"paymentOption,omitempty"`
	// The product types covered by the savings plan, e.g., `EC2`, `Lambda`.
	ProductTypes []string `protobuf:"bytes,11,rep,name=productTypes,proto3" json:"productTypes,omitempty"`
	// The EC2 instance families covered by the savings plan, e.g., `m5`, `c5`.
	Ec2InstanceFamily []string `protobuf:"bytes,12,rep,name=ec2InstanceFamily,proto3" json:"ec2InstanceFamily,omitempty"`
	// The periodic (usually monthly) charge to pay over the term of the plan.
	RecurringPaymentAmount float64 `protobuf:"fixed64,13,opt,name=recurringPaymentAmount,proto3" json:"recurringPaymentAmount,omitempty"`
	// The total amount paid at the start of the Savings Plan, if applicable.
	UpfrontPaymentAmount float64 `protobuf:"fixed64,14,opt,name=upfrontPaymentAmount,proto3" json:"upfrontPaymentAmount,omitempty"`
	// The tag that refers to the one who purchased the Savings Plan.
	Tags string `protobuf:"bytes,15,opt,name=tags,proto3" json:"tags,omitempty"`
	// contains filtered or unexported fields
}

Savings Plan Details to be used in the GetDailyUsageCostDetailsResponse.

func (*SpDetails) Descriptor deprecated added in v0.76.20

func (*SpDetails) Descriptor() ([]byte, []int)

Deprecated: Use SpDetails.ProtoReflect.Descriptor instead.

func (*SpDetails) GetCommitment added in v0.76.20

func (x *SpDetails) GetCommitment() float64

func (*SpDetails) GetCurrency added in v0.76.20

func (x *SpDetails) GetCurrency() string

func (*SpDetails) GetDescription added in v0.76.20

func (x *SpDetails) GetDescription() string

func (*SpDetails) GetEc2InstanceFamily added in v0.76.20

func (x *SpDetails) GetEc2InstanceFamily() []string

func (*SpDetails) GetEndTime added in v0.76.20

func (x *SpDetails) GetEndTime() string

func (*SpDetails) GetPayerId added in v0.76.20

func (x *SpDetails) GetPayerId() string

func (*SpDetails) GetPaymentOption added in v0.76.20

func (x *SpDetails) GetPaymentOption() string

func (*SpDetails) GetProductTypes added in v0.76.20

func (x *SpDetails) GetProductTypes() []string

func (*SpDetails) GetRecurringPaymentAmount added in v0.76.20

func (x *SpDetails) GetRecurringPaymentAmount() float64

func (*SpDetails) GetReturnableUntil added in v0.76.20

func (x *SpDetails) GetReturnableUntil() string

func (*SpDetails) GetSavingsPlanType added in v0.76.20

func (x *SpDetails) GetSavingsPlanType() string

func (*SpDetails) GetStartTime added in v0.76.20

func (x *SpDetails) GetStartTime() string

func (*SpDetails) GetState added in v0.76.20

func (x *SpDetails) GetState() string

func (*SpDetails) GetTags added in v0.76.20

func (x *SpDetails) GetTags() string

func (*SpDetails) GetUpfrontPaymentAmount added in v0.76.20

func (x *SpDetails) GetUpfrontPaymentAmount() float64

func (*SpDetails) ProtoMessage added in v0.76.20

func (*SpDetails) ProtoMessage()

func (*SpDetails) ProtoReflect added in v0.76.20

func (x *SpDetails) ProtoReflect() protoreflect.Message

func (*SpDetails) Reset added in v0.76.20

func (x *SpDetails) Reset()

func (*SpDetails) String added in v0.76.20

func (x *SpDetails) String() string

type UnimplementedFlowServer

type UnimplementedFlowServer struct {
}

UnimplementedFlowServer must be embedded to have forward compatible implementations.

func (UnimplementedFlowServer) CreateCostExplorerAccess added in v0.75.97

func (UnimplementedFlowServer) CreateSettings added in v0.74.67

func (UnimplementedFlowServer) GetCostExplorerAccessTemplateUrl added in v0.75.94

func (UnimplementedFlowServer) GetDailyUsageCostDetails added in v0.76.12

func (UnimplementedFlowServer) GetInfo

func (UnimplementedFlowServer) GetRecommendationDetails added in v0.75.86

func (UnimplementedFlowServer) GetSettings added in v0.75.61

func (UnimplementedFlowServer) GetSettingsHistory added in v0.75.96

func (UnimplementedFlowServer) UpdateSettings added in v0.75.61

type UnsafeFlowServer

type UnsafeFlowServer interface {
	// contains filtered or unexported methods
}

UnsafeFlowServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to FlowServer will result in compilation errors.

type UpdateSettingsRequest added in v0.75.61

type UpdateSettingsRequest struct {

	// Required. The id of the payer to update.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// Optional. Update account scope (payer or linked).
	AccountScope *string `protobuf:"bytes,2,opt,name=accountScope,proto3,oneof" json:"accountScope,omitempty"`
	// Optional. Update customization setting.
	Customization *string `protobuf:"bytes,3,opt,name=customization,proto3,oneof" json:"customization,omitempty"`
	// Optional. Update term of the SP.
	PlanTerm *string `protobuf:"bytes,4,opt,name=planTerm,proto3,oneof" json:"planTerm,omitempty"`
	// Optional. Update payment option.
	PaymentOption *string `protobuf:"bytes,5,opt,name=paymentOption,proto3,oneof" json:"paymentOption,omitempty"`
	// Optional. Update lookback period.
	LookBackPeriod *string `protobuf:"bytes,6,opt,name=lookBackPeriod,proto3,oneof" json:"lookBackPeriod,omitempty"`
	// Optional. Update list of instance families.
	InstanceFamily *string `protobuf:"bytes,7,opt,name=instanceFamily,proto3,oneof" json:"instanceFamily,omitempty"`
	// Optional. Update annual budget.
	AnnualBudget *float64 `protobuf:"fixed64,8,opt,name=annualBudget,proto3,oneof" json:"annualBudget,omitempty"`
	// Optional. Update purchase approval.
	Approval *bool `protobuf:"varint,9,opt,name=approval,proto3,oneof" json:"approval,omitempty"`
	// Optional. Update used payerId.
	PayerId *string `protobuf:"bytes,10,opt,name=payerId,proto3,oneof" json:"payerId,omitempty"`
	// contains filtered or unexported fields
}

Request message for the Flow.UpdateSettings rpc.

func (*UpdateSettingsRequest) Descriptor deprecated added in v0.75.61

func (*UpdateSettingsRequest) Descriptor() ([]byte, []int)

Deprecated: Use UpdateSettingsRequest.ProtoReflect.Descriptor instead.

func (*UpdateSettingsRequest) GetAccountScope added in v0.75.61

func (x *UpdateSettingsRequest) GetAccountScope() string

func (*UpdateSettingsRequest) GetAnnualBudget added in v0.75.61

func (x *UpdateSettingsRequest) GetAnnualBudget() float64

func (*UpdateSettingsRequest) GetApproval added in v0.75.61

func (x *UpdateSettingsRequest) GetApproval() bool

func (*UpdateSettingsRequest) GetCustomization added in v0.75.61

func (x *UpdateSettingsRequest) GetCustomization() string

func (*UpdateSettingsRequest) GetId added in v0.75.61

func (x *UpdateSettingsRequest) GetId() string

func (*UpdateSettingsRequest) GetInstanceFamily added in v0.75.61

func (x *UpdateSettingsRequest) GetInstanceFamily() string

func (*UpdateSettingsRequest) GetLookBackPeriod added in v0.75.61

func (x *UpdateSettingsRequest) GetLookBackPeriod() string

func (*UpdateSettingsRequest) GetPayerId added in v0.75.72

func (x *UpdateSettingsRequest) GetPayerId() string

func (*UpdateSettingsRequest) GetPaymentOption added in v0.75.61

func (x *UpdateSettingsRequest) GetPaymentOption() string

func (*UpdateSettingsRequest) GetPlanTerm added in v0.75.61

func (x *UpdateSettingsRequest) GetPlanTerm() string

func (*UpdateSettingsRequest) ProtoMessage added in v0.75.61

func (*UpdateSettingsRequest) ProtoMessage()

func (*UpdateSettingsRequest) ProtoReflect added in v0.75.61

func (x *UpdateSettingsRequest) ProtoReflect() protoreflect.Message

func (*UpdateSettingsRequest) Reset added in v0.75.61

func (x *UpdateSettingsRequest) Reset()

func (*UpdateSettingsRequest) String added in v0.75.61

func (x *UpdateSettingsRequest) String() string

type UpdateSettingsResponse added in v0.75.61

type UpdateSettingsResponse struct {
	Response string `protobuf:"bytes,1,opt,name=response,proto3" json:"response,omitempty"`
	// contains filtered or unexported fields
}

func (*UpdateSettingsResponse) Descriptor deprecated added in v0.75.61

func (*UpdateSettingsResponse) Descriptor() ([]byte, []int)

Deprecated: Use UpdateSettingsResponse.ProtoReflect.Descriptor instead.

func (*UpdateSettingsResponse) GetResponse added in v0.75.61

func (x *UpdateSettingsResponse) GetResponse() string

func (*UpdateSettingsResponse) ProtoMessage added in v0.75.61

func (*UpdateSettingsResponse) ProtoMessage()

func (*UpdateSettingsResponse) ProtoReflect added in v0.75.61

func (x *UpdateSettingsResponse) ProtoReflect() protoreflect.Message

func (*UpdateSettingsResponse) Reset added in v0.75.61

func (x *UpdateSettingsResponse) Reset()

func (*UpdateSettingsResponse) String added in v0.75.61

func (x *UpdateSettingsResponse) String() string

type UsageCostDetails added in v0.76.12

type UsageCostDetails struct {

	// The specific date this entry represents, corresponding to one day within the requested date range.
	CurrentDate string `protobuf:"bytes,1,opt,name=currentDate,proto3" json:"currentDate,omitempty"`
	// The product code for which the usage and cost details are provided.
	ProductCode string `protobuf:"bytes,2,opt,name=productCode,proto3" json:"productCode,omitempty"`
	// Total On-Demand usage in hours for the date.
	OndemandUsage float64 `protobuf:"fixed64,3,opt,name=ondemandUsage,proto3" json:"ondemandUsage,omitempty"`
	// Total On-Demand cost in USD for the date.
	OndemandCost float64 `protobuf:"fixed64,4,opt,name=ondemandCost,proto3" json:"ondemandCost,omitempty"`
	// Total Reserved Instance usage in hours for the date.
	ReservedUsage float64 `protobuf:"fixed64,5,opt,name=reservedUsage,proto3" json:"reservedUsage,omitempty"`
	// Total Reserved Instance cost in USD for the date.
	ReservedCost float64 `protobuf:"fixed64,6,opt,name=reservedCost,proto3" json:"reservedCost,omitempty"`
	// Total Savings Plan usage in hours for the date purchased by Flow.
	SavingsPlanUsageByFlow float64 `protobuf:"fixed64,7,opt,name=savingsPlanUsageByFlow,proto3" json:"savingsPlanUsageByFlow,omitempty"`
	// Total Savings Plan cost in USD for the date purchased by Flow.
	SavingsPlanCostByFlow float64 `protobuf:"fixed64,8,opt,name=savingsPlanCostByFlow,proto3" json:"savingsPlanCostByFlow,omitempty"`
	// Total Savings Plan usage in hours for the date purchased by user.
	SavingsPlanUsageByUser float64 `protobuf:"fixed64,9,opt,name=savingsPlanUsageByUser,proto3" json:"savingsPlanUsageByUser,omitempty"`
	// Total Savings Plan cost in USD for the date purchased by user.
	SavingsPlanCostByUser float64 `protobuf:"fixed64,10,opt,name=savingsPlanCostByUser,proto3" json:"savingsPlanCostByUser,omitempty"`
	// Total Spot Instance usage in hours for the date.
	SpotUsage float64 `protobuf:"fixed64,11,opt,name=spotUsage,proto3" json:"spotUsage,omitempty"`
	// Total Spot Instance cost in USD for the date.
	SpotCost float64 `protobuf:"fixed64,12,opt,name=spotCost,proto3" json:"spotCost,omitempty"`
	// contains filtered or unexported fields
}

Usage and Cost Details to be used in the GetDailyUsageCostDetailsResponse.

func (*UsageCostDetails) Descriptor deprecated added in v0.76.12

func (*UsageCostDetails) Descriptor() ([]byte, []int)

Deprecated: Use UsageCostDetails.ProtoReflect.Descriptor instead.

func (*UsageCostDetails) GetCurrentDate added in v0.76.12

func (x *UsageCostDetails) GetCurrentDate() string

func (*UsageCostDetails) GetOndemandCost added in v0.76.12

func (x *UsageCostDetails) GetOndemandCost() float64

func (*UsageCostDetails) GetOndemandUsage added in v0.76.12

func (x *UsageCostDetails) GetOndemandUsage() float64

func (*UsageCostDetails) GetProductCode added in v0.76.18

func (x *UsageCostDetails) GetProductCode() string

func (*UsageCostDetails) GetReservedCost added in v0.76.12

func (x *UsageCostDetails) GetReservedCost() float64

func (*UsageCostDetails) GetReservedUsage added in v0.76.12

func (x *UsageCostDetails) GetReservedUsage() float64

func (*UsageCostDetails) GetSavingsPlanCostByFlow added in v0.76.18

func (x *UsageCostDetails) GetSavingsPlanCostByFlow() float64

func (*UsageCostDetails) GetSavingsPlanCostByUser added in v0.76.18

func (x *UsageCostDetails) GetSavingsPlanCostByUser() float64

func (*UsageCostDetails) GetSavingsPlanUsageByFlow added in v0.76.18

func (x *UsageCostDetails) GetSavingsPlanUsageByFlow() float64

func (*UsageCostDetails) GetSavingsPlanUsageByUser added in v0.76.18

func (x *UsageCostDetails) GetSavingsPlanUsageByUser() float64

func (*UsageCostDetails) GetSpotCost added in v0.76.12

func (x *UsageCostDetails) GetSpotCost() float64

func (*UsageCostDetails) GetSpotUsage added in v0.76.12

func (x *UsageCostDetails) GetSpotUsage() float64

func (*UsageCostDetails) ProtoMessage added in v0.76.12

func (*UsageCostDetails) ProtoMessage()

func (*UsageCostDetails) ProtoReflect added in v0.76.12

func (x *UsageCostDetails) ProtoReflect() protoreflect.Message

func (*UsageCostDetails) Reset added in v0.76.12

func (x *UsageCostDetails) Reset()

func (*UsageCostDetails) String added in v0.76.12

func (x *UsageCostDetails) String() string

Jump to